/**
  *	Copyright (C) @YEAR@ Vernon Systems Limited
  *
  *	Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), 
  *	to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, 
  *	and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
  *
  *	The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
  *
  *	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  *	FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
  *	WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
package com.ehive.api;


import com.ehive.api.dao.accounts.AccountsDao;
import com.ehive.api.dao.comments.CommentsDao;
import com.ehive.api.dao.interestingobjectrecords.InterestingObjectRecordsDao;
import com.ehive.api.dao.objectrecords.ObjectRecordsDao;
import com.ehive.api.dao.objectrecordtags.ObjectRecordTagsDao;
import com.ehive.api.dao.popularobjectrecords.PopularObjectRecordsDao;
import com.ehive.api.dao.recentobjectrecords.RecentObjectRecordsDao;
import com.ehive.api.dao.tagcloud.TagCloudDao;
import com.ehive.api.domain.accounts.Account;
import com.ehive.api.domain.comments.Comment;
import com.ehive.api.domain.comments.CommentsCollection;
import com.ehive.api.domain.objects.ObjectRecord;
import com.ehive.api.domain.objects.ObjectRecordsCollection;
import com.ehive.api.domain.tags.ObjectRecordTag;
import com.ehive.api.domain.tags.ObjectRecordTagsCollection;
import com.ehive.api.domain.tags.TagCloud;
import com.ehive.api.exceptions.EHiveApiException;
import com.ehive.api.exceptions.EHiveFatalServerException;
import com.ehive.api.exceptions.EHiveForbiddenException;
import com.ehive.api.exceptions.EHiveNotFoundException;
import com.ehive.api.exceptions.EHiveUnauthorizedException;
import com.ehive.api.transport.Transport;

public class EHiveApi {
	
	protected Transport transport;

	
	public EHiveApi() throws EHiveApiException {
		this.transport = new Transport();
	}
	
	public void setOAuthCredentials(final String clientId, final String clientSecret, final String trackingId) {
		transport.setClientId(clientId);
		transport.setClientSecret(clientSecret);
		transport.setTrackingId(trackingId);
	}

	public void setApiUrl(String apiUrl) {
		transport.setApiUrl(apiUrl);
	}

	
	public EHiveApi(final String clientId, final String clientSecret, final String trackingId, final String pathToOauthPropertiesFile) throws EHiveApiException {
		this.transport = new Transport(clientId, clientSecret, trackingId, pathToOauthPropertiesFile);
	}	
	
	public EHiveApi(final String clientId, final String clientSecret, final String trackingId) throws EHiveApiException {
		this.transport = new Transport(clientId, clientSecret, trackingId);
	}	
	
	public EHiveApi(final String pathToOauthPropertiesFile) throws EHiveApiException {
		this.transport = new Transport(pathToOauthPropertiesFile);
	}

	//
	//	Object Records
	//
	public ObjectRecord getObjectRecord(Long objectRecordId) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		ObjectRecordsDao objectsDao = new ObjectRecordsDao(this.transport);
		ObjectRecord objectRecord = objectsDao.getObjectRecord(objectRecordId);
		return objectRecord;
	}
	
	public ObjectRecordsCollection getObjectRecordsInEHive(String query, Boolean hasImages, String sort, String direction, Integer offset, Integer limit ) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		ObjectRecordsDao objectsDao = new ObjectRecordsDao(this.transport);
		ObjectRecordsCollection objectRecordsCollection = objectsDao.getObjectRecordsInEHive( query, hasImages, sort, direction, offset, limit );
		return objectRecordsCollection;
	}
	
	public ObjectRecordsCollection getObjectRecordsInAccount(Integer accountId, String query, Boolean hasImages, String sort, String direction, Integer offset, Integer limit ) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		ObjectRecordsDao objectsDao = new ObjectRecordsDao(this.transport);
		ObjectRecordsCollection objectRecordsCollection = objectsDao.getObjectRecordsInAccount(accountId, query, hasImages, sort, direction, offset, limit);
		return objectRecordsCollection;		
	}
	
	public ObjectRecordsCollection getObjectRecordsInCommunity(Integer communityId, String query, Boolean hasImages, String sort, String direction, Integer offset, Integer limit) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		ObjectRecordsDao objectsDao = new ObjectRecordsDao(this.transport);
		ObjectRecordsCollection objectRecordsCollection = objectsDao.getObjectRecordsInCommunity( communityId, query, hasImages, sort, direction, offset, limit );
		return objectRecordsCollection;
	}

	public ObjectRecordsCollection getObjectRecordsInAccountInCommunity(Integer communityId, Integer accountId, String query, Boolean hasImages, String sort, String direction, Integer offset, Integer limit ) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		ObjectRecordsDao objectsDao = new ObjectRecordsDao(this.transport);
		ObjectRecordsCollection objectRecordsCollection = objectsDao.getObjectRecordsInAccountInCommunity(communityId, accountId, query, hasImages, sort, direction, offset, limit);
		return objectRecordsCollection;
	}
	
	
	//
	// Interesting Object Records
	//
	public ObjectRecordsCollection getInterestingObjectRecordsInEHive(Boolean hasImages, Integer offset, Integer limit) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		InterestingObjectRecordsDao interestingObjectRecordsDao = new InterestingObjectRecordsDao(this.transport);
		ObjectRecordsCollection objectRecordsCollection = interestingObjectRecordsDao.getInterestingObjectRecordsInEHive(hasImages, offset, limit);
		return objectRecordsCollection;		
	}
	
	public ObjectRecordsCollection getInterestingObjectRecordsInEHive(Boolean hasImages, String catalogueType, Integer offset, Integer limit) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		InterestingObjectRecordsDao interestingObjectRecordsDao = new InterestingObjectRecordsDao(this.transport);
		ObjectRecordsCollection objectRecordsCollection = interestingObjectRecordsDao.getInterestingObjectRecordsInEHive(hasImages, catalogueType, offset, limit);
		return objectRecordsCollection;		
	}
	
	public ObjectRecordsCollection getInterestingObjectRecordsInAccount(Integer accountId, Boolean hasImages, Integer offset, Integer limit) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		InterestingObjectRecordsDao interestingObjectRecordsDao = new InterestingObjectRecordsDao(this.transport);
		ObjectRecordsCollection objectRecordsCollection = interestingObjectRecordsDao.getInterestingObjectRecordsInAccount(accountId, hasImages, offset, limit);
		return objectRecordsCollection;
	}
	
	public ObjectRecordsCollection getInterestingObjectRecordsInAccount(Integer accountId, Boolean hasImages, String catalogueType, Integer offset, Integer limit) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		InterestingObjectRecordsDao interestingObjectRecordsDao = new InterestingObjectRecordsDao(this.transport);
		ObjectRecordsCollection objectRecordsCollection = interestingObjectRecordsDao.getInterestingObjectRecordsInAccount(accountId, hasImages, catalogueType, offset, limit);
		return objectRecordsCollection;
	}
	
	public ObjectRecordsCollection getInterestingObjectRecordsInCommunity(Integer communityId, Boolean hasImages, Integer offset, Integer limit) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		InterestingObjectRecordsDao interestingObjectRecordsDao = new InterestingObjectRecordsDao(this.transport);
		ObjectRecordsCollection objectRecordsCollection = interestingObjectRecordsDao.getInterestingObjectRecordsInCommunity(communityId, hasImages, offset, limit);
		return objectRecordsCollection;
	}
	
	public ObjectRecordsCollection getInterestingObjectRecordsInCommunity(Integer communityId, Boolean hasImages, String catalogueType, Integer offset, Integer limit) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		InterestingObjectRecordsDao interestingObjectRecordsDao = new InterestingObjectRecordsDao(this.transport);
		ObjectRecordsCollection objectRecordsCollection = interestingObjectRecordsDao.getInterestingObjectRecordsInCommunity(communityId, hasImages, catalogueType, offset, limit);
		return objectRecordsCollection;
	}
	
	public ObjectRecordsCollection getInterestingObjectRecordsInAccountInCommunity(Integer communityId, Integer accountId, Boolean hasImages, Integer offset, Integer limit) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		InterestingObjectRecordsDao interestingObjectRecordsDao = new InterestingObjectRecordsDao(this.transport);
		ObjectRecordsCollection objectRecordsCollection = interestingObjectRecordsDao.getInterestingObjectRecordsInAccountInCommunity(communityId, accountId, hasImages, offset, limit);
		return objectRecordsCollection;
	}
	
	public ObjectRecordsCollection getInterestingObjectRecordsInAccountInCommunity(Integer communityId, Integer accountId, Boolean hasImages, String catalogueType, Integer offset, Integer limit) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		InterestingObjectRecordsDao interestingObjectRecordsDao = new InterestingObjectRecordsDao(this.transport);
		ObjectRecordsCollection objectRecordsCollection = interestingObjectRecordsDao.getInterestingObjectRecordsInAccountInCommunity(communityId, accountId, hasImages, catalogueType, offset, limit);
		return objectRecordsCollection;
	}
	
	//
	// Popular Object Records
	//
	public ObjectRecordsCollection getPopularObjectRecordsInEHive(Boolean hasImages, Integer offset, Integer limit) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		PopularObjectRecordsDao popularPopularObjectRecordsDao = new PopularObjectRecordsDao(this.transport);
		ObjectRecordsCollection objectRecordsCollection = popularPopularObjectRecordsDao.getPopularObjectRecordsInEHive(hasImages, offset, limit);
		return objectRecordsCollection;
	}
	
	public ObjectRecordsCollection getPopularObjectRecordsInEHive(Boolean hasImages, String catalogueType, Integer offset, Integer limit) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		PopularObjectRecordsDao popularPopularObjectRecordsDao = new PopularObjectRecordsDao(this.transport);
		ObjectRecordsCollection objectRecordsCollection = popularPopularObjectRecordsDao.getPopularObjectRecordsInEHive(hasImages, catalogueType, offset, limit);
		return objectRecordsCollection;
	}
	
	public ObjectRecordsCollection getPopularObjectRecordsInAccount(Integer accountId, Boolean hasImages, Integer offset, Integer limit) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		PopularObjectRecordsDao popularPopularObjectRecordsDao = new PopularObjectRecordsDao(this.transport);
		ObjectRecordsCollection objectRecordsCollection = popularPopularObjectRecordsDao.getPopularObjectRecordsInAccount(accountId, hasImages, offset, limit);
		return objectRecordsCollection;
	}
	
	public ObjectRecordsCollection getPopularObjectRecordsInAccount(Integer accountId, Boolean hasImages, String catalogueType, Integer offset, Integer limit) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		PopularObjectRecordsDao popularPopularObjectRecordsDao = new PopularObjectRecordsDao(this.transport);
		ObjectRecordsCollection objectRecordsCollection = popularPopularObjectRecordsDao.getPopularObjectRecordsInAccount(accountId, hasImages, catalogueType, offset, limit);
		return objectRecordsCollection;
	}
	
	public ObjectRecordsCollection getPopularObjectRecordsInCommunity(Integer communityId, Boolean hasImages, Integer offset, Integer limit) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		PopularObjectRecordsDao popularPopularObjectRecordsDao = new PopularObjectRecordsDao(this.transport);
		ObjectRecordsCollection objectRecordsCollection = popularPopularObjectRecordsDao.getPopularObjectRecordsInCommunity(communityId, hasImages, offset, limit);
		return objectRecordsCollection;
	}
	
	public ObjectRecordsCollection getPopularObjectRecordsInCommunity(Integer communityId, Boolean hasImages, String catalogueType, Integer offset, Integer limit) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		PopularObjectRecordsDao popularPopularObjectRecordsDao = new PopularObjectRecordsDao(this.transport);
		ObjectRecordsCollection objectRecordsCollection = popularPopularObjectRecordsDao.getPopularObjectRecordsInCommunity(communityId, hasImages, catalogueType,  offset, limit);
		return objectRecordsCollection;
	}
	
	public ObjectRecordsCollection getPopularObjectRecordsInAccountInCommunity(Integer communityId, Integer accountId, Boolean hasImages, Integer offset, Integer limit) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		PopularObjectRecordsDao popularPopularObjectRecordsDao = new PopularObjectRecordsDao(this.transport);
		ObjectRecordsCollection objectRecordsCollection = popularPopularObjectRecordsDao.getPopularObjectRecordsInAccountInCommunity(communityId, accountId, hasImages, offset, limit);
		return objectRecordsCollection;
	}
	
	public ObjectRecordsCollection getPopularObjectRecordsInAccountInCommunity(Integer communityId, Integer accountId, Boolean hasImages, String catalogueType, Integer offset, Integer limit) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		PopularObjectRecordsDao popularPopularObjectRecordsDao = new PopularObjectRecordsDao(this.transport);
		ObjectRecordsCollection objectRecordsCollection = popularPopularObjectRecordsDao.getPopularObjectRecordsInAccountInCommunity(communityId, accountId, hasImages, catalogueType, offset, limit);
		return objectRecordsCollection;
	}
	
	//
	// Recent Object Records
	//
	public ObjectRecordsCollection getRecentObjectRecordsInEHive(Boolean hasImages, Integer offset, Integer limit) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		RecentObjectRecordsDao recentObjectRecordsDao = new RecentObjectRecordsDao(this.transport);
		ObjectRecordsCollection objectRecordsCollection = recentObjectRecordsDao.getRecentObjectRecordsInEHive(hasImages, offset, limit);
		return objectRecordsCollection;
	}
	
	public ObjectRecordsCollection getRecentObjectRecordsInEHive(Boolean hasImages, String catalogueType, Integer offset, Integer limit) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		RecentObjectRecordsDao recentObjectRecordsDao = new RecentObjectRecordsDao(this.transport);
		ObjectRecordsCollection objectRecordsCollection = recentObjectRecordsDao.getRecentObjectRecordsInEHive(hasImages, catalogueType, offset, limit);
		return objectRecordsCollection;
	}
	
	public ObjectRecordsCollection getRecentObjectRecordsInAccount(Integer accountId, Boolean hasImages, Integer offset, Integer limit) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		RecentObjectRecordsDao recentObjectRecordsDao = new RecentObjectRecordsDao(this.transport);
		ObjectRecordsCollection objectRecordsCollection = recentObjectRecordsDao.getRecentObjectRecordsInAccount(accountId, hasImages, offset, limit);
		return objectRecordsCollection;
	}
	
	public ObjectRecordsCollection getRecentObjectRecordsInAccount(Integer accountId, Boolean hasImages, String catalogueType, Integer offset, Integer limit) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		RecentObjectRecordsDao recentObjectRecordsDao = new RecentObjectRecordsDao(this.transport);
		ObjectRecordsCollection objectRecordsCollection = recentObjectRecordsDao.getRecentObjectRecordsInAccount(accountId, hasImages, catalogueType,offset, limit);
		return objectRecordsCollection;
	}
	
	public ObjectRecordsCollection getRecentObjectRecordsInCommunity(Integer communityId, Boolean hasImages, Integer offset, Integer limit) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException{
		RecentObjectRecordsDao recentObjectRecordsDao = new RecentObjectRecordsDao(this.transport);
		ObjectRecordsCollection objectRecordsCollection = recentObjectRecordsDao.getRecentObjectRecordsInCommunity(communityId, hasImages, offset, limit);
		return objectRecordsCollection;
	}
	
	public ObjectRecordsCollection getRecentObjectRecordsInCommunity(Integer communityId, Boolean hasImages, String catalogueType, Integer offset, Integer limit) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException{
		RecentObjectRecordsDao recentObjectRecordsDao = new RecentObjectRecordsDao(this.transport);
		ObjectRecordsCollection objectRecordsCollection = recentObjectRecordsDao.getRecentObjectRecordsInCommunity(communityId, hasImages, catalogueType, offset, limit);
		return objectRecordsCollection;
	}
	
	public ObjectRecordsCollection getRecentObjectRecordsInAccountInCommunity(Integer communityId, Integer accountId, Boolean hasImages, Integer offset, Integer limit) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException{
		RecentObjectRecordsDao recentObjectRecordsDao = new RecentObjectRecordsDao(this.transport);
		ObjectRecordsCollection objectRecordsCollection = recentObjectRecordsDao.getRecentObjectRecordsInAccountInCommunity(communityId, accountId, hasImages, offset, limit);
		return objectRecordsCollection;
	}
	
	public ObjectRecordsCollection getRecentObjectRecordsInAccountInCommunity(Integer communityId, Integer accountId, Boolean hasImages, String catalogueType, Integer offset, Integer limit) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException{
		RecentObjectRecordsDao recentObjectRecordsDao = new RecentObjectRecordsDao(this.transport);
		ObjectRecordsCollection objectRecordsCollection = recentObjectRecordsDao.getRecentObjectRecordsInAccountInCommunity(communityId, accountId, hasImages, catalogueType, offset, limit);
		return objectRecordsCollection;
	}
	

	//
	// Account
	//
	public Account getAccount(Integer accountId) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		AccountsDao accountsDao = new AccountsDao(this.transport);
		Account account = accountsDao.getAccount(accountId);
		return account;
	}
	
	public Account getAccountInCommunity(Integer communityId, Integer accountId) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		AccountsDao accountsDao = new AccountsDao(this.transport);
		Account account = accountsDao.getAccountInCommunity(communityId, accountId);
		return account;
	}	
	
	//
	// Object Comments
	//
	public CommentsCollection getObjectRecordComments(Long objectRecordId, Integer offset, Integer limit) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		CommentsDao commentsDao = new CommentsDao(this.transport);
		CommentsCollection commentsCollection = commentsDao.getComments(objectRecordId, offset, limit);
		return commentsCollection;
	}
	
	public Comment addObjectRecordComment(Long objectRecordId, Comment comment) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		CommentsDao commentsDao = new CommentsDao(this.transport);
		comment = commentsDao.addComment(objectRecordId, comment);
		return comment;
	}
	
	//
	// Object Record Tags
	//
	public ObjectRecordTagsCollection getObjectRecordTags(Long objectRecordId) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		ObjectRecordTagsDao objectRecordTagsDao = new ObjectRecordTagsDao(this.transport);
		ObjectRecordTagsCollection objectTagsCollection = objectRecordTagsDao.getObjectRecordTags(objectRecordId);
		return objectTagsCollection;
	}
	
	public ObjectRecordTag addObjectRecordTag(Long objectRecordId, ObjectRecordTag objectTag) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		ObjectRecordTagsDao objectRecordTagsDao = new ObjectRecordTagsDao(this.transport);
		objectTag = objectRecordTagsDao.addObjectRecordTag(objectRecordId, objectTag);
		return objectTag;
	}
	
	public ObjectRecordTag deleteObjectRecordTag(Long objectRecordId, ObjectRecordTag objectTag) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		ObjectRecordTagsDao objectRecordTagsDao = new ObjectRecordTagsDao(this.transport);
		objectTag = objectRecordTagsDao.deleteObjectRecordTag(objectRecordId, objectTag);
		return objectTag;
	}

	//
	// Tags Cloud 
	//
	public TagCloud getTagCloudInAccount(Integer accountId, Integer limit) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		TagCloudDao tagCloudDao = new TagCloudDao(this.transport);
		TagCloud tagCloud = tagCloudDao.getTagCloudInAccount(accountId, limit);
		return tagCloud;
	}
	
	public TagCloud getTagCloudInCommunity(Integer communityId, Integer limit) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		TagCloudDao tagCloudDao = new TagCloudDao(this.transport);
		TagCloud tagCloud = tagCloudDao.getTagCloudInCommunity(communityId, limit);
		return tagCloud;
	}
	
	public TagCloud getTagCloudInEHive(Integer limit) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		TagCloudDao tagCloudDao = new TagCloudDao(this.transport);
		TagCloud tagCloud = tagCloudDao.getTagCloudInEHive(limit);
		return tagCloud;
	}
	
}
