/**
  *	Copyright (C) @YEAR@ Vernon Systems Limited
  *
  *	Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), 
  *	to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, 
  *	and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
  *
  *	The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
  *
  *	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  *	FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
  *	WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
package com.ehive.api.dao.accounts;

import com.ehive.api.domain.accounts.Account;
import com.ehive.api.exceptions.EHiveApiException;
import com.ehive.api.exceptions.EHiveFatalServerException;
import com.ehive.api.exceptions.EHiveForbiddenException;
import com.ehive.api.exceptions.EHiveNotFoundException;
import com.ehive.api.exceptions.EHiveUnauthorizedException;
import com.ehive.api.transport.EHiveApiConstants;
import com.ehive.api.transport.Transport;
import com.google.gson.Gson;

public class AccountsDao {

	private Transport transport;
	private Gson gson;
	
	public AccountsDao(Transport transport) {
		this.transport = transport;
		this.gson = new Gson();
	}

	public Account getAccount(Integer accountId) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		String path = EHiveApiConstants.VERSION_ID + "/accounts/" + accountId;
		String json = this.transport.get(path, null);
		return this.gson.fromJson(json, Account.class);
	}

	public Account getAccountInCommunity(Integer communityId, Integer accountId) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		String path = EHiveApiConstants.VERSION_ID + "/communities/" + communityId + "/accounts/" + accountId;
		String json = this.transport.get(path, null);
		return this.gson.fromJson(json, Account.class);
	}

}