/**
  *	Copyright (C) @YEAR@ Vernon Systems Limited
  *
  *	Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), 
  *	to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, 
  *	and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
  *
  *	The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
  *
  *	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  *	FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
  *	WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
package com.ehive.api.dao.objectrecords;

import java.io.File;

import com.ehive.api.dao.DaoHelper;
import com.ehive.api.domain.objects.ObjectRecord;
import com.ehive.api.domain.objects.ObjectRecordsCollection;
import com.ehive.api.exceptions.EHiveApiException;
import com.ehive.api.exceptions.EHiveFatalServerException;
import com.ehive.api.exceptions.EHiveForbiddenException;
import com.ehive.api.exceptions.EHiveNotFoundException;
import com.ehive.api.exceptions.EHiveUnauthorizedException;
import com.ehive.api.transport.EHiveApiConstants;
import com.ehive.api.transport.Transport;
import com.google.gson.Gson;


public class ObjectRecordsDao {

	private Transport transport;
	private Gson gson;
	
	public ObjectRecordsDao(Transport transport) {
		this.transport = transport;
		this.gson = new Gson();
	}

	public ObjectRecord getObjectRecord(Long objectRecordId) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		String path = EHiveApiConstants.VERSION_ID + "/objectrecords/" + objectRecordId;
		String json = this.transport.get(path, null);
		return this.gson.fromJson(json, ObjectRecord.class) ;
	}
	
	public ObjectRecordsCollection getObjectRecordsInEHive(String query, Boolean hasImages, String sort, String direction, Integer offset, Integer limit) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		String path = EHiveApiConstants.VERSION_ID + File.separator + "objectrecords";
		String queryString = DaoHelper.getObjectsQueryString(query, hasImages, sort, direction, offset, limit);
		String json = this.transport.get(path, queryString);
		return this.gson.fromJson(json, ObjectRecordsCollection.class);	
	}

	public ObjectRecordsCollection getObjectRecordsInAccount(Integer accountId, String query, Boolean hasImages, String sort, String direction, Integer offset, Integer limit) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		String path = EHiveApiConstants.VERSION_ID + "/accounts/" + accountId + "/objectrecords";
		String queryString = DaoHelper.getObjectsQueryString(query, hasImages, sort, direction, offset, limit);
		String json = this.transport.get(path, queryString);
		return this.gson.fromJson(json, ObjectRecordsCollection.class);
	}

	public ObjectRecordsCollection getObjectRecordsInCommunity(Integer communityId, String query, Boolean hasImages, String sort, String direction, Integer offset, Integer limit) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		String path = EHiveApiConstants.VERSION_ID + "/communities/" + communityId + "/objectrecords";
		String queryString = DaoHelper.getObjectsQueryString(query, hasImages, sort, direction, offset, limit);
		String json = this.transport.get(path, queryString);
		return this.gson.fromJson(json, ObjectRecordsCollection.class);
	}

	public ObjectRecordsCollection getObjectRecordsInAccountInCommunity( Integer communityId, Integer accountId, String query, Boolean hasImages, String sort, String direction, Integer offset, Integer limit) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		String path = EHiveApiConstants.VERSION_ID + "/communities/" + communityId + "/accounts/"+ accountId + "/objectrecords";
		String queryString = DaoHelper.getObjectsQueryString(query, hasImages, sort, direction, offset, limit);
		String json = this.transport.get(path, queryString);
		return this.gson.fromJson(json, ObjectRecordsCollection.class);
	}

}
