/**
  *	Copyright (C) @YEAR@ Vernon Systems Limited
  *
  *	Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), 
  *	to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, 
  *	and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
  *
  *	The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
  *
  *	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  *	FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
  *	WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
package com.ehive.api.domain.objects;

import java.io.Serializable;

import com.ehive.api.exceptions.EHiveApiException;

public class Attribute implements Serializable {

	private static final long serialVersionUID = 3414631627915660151L;
		
	private String key;
	private Object value;

	public Attribute() {}
		
	public Attribute( String key, Object value) throws EHiveApiException {
		if (!AttributeIdentifier.isValid(key)) throw new EHiveApiException("The Attribute key entered was not a valid eHive Attribute identifier: \"" + key + "\". \nPlease check the API docs online for a list of valid Field identifiers.");
		
		this.key = key;
		this.value = value;		
		
	}
	
	public Attribute( AttributeIdentifier key, Object value) {
		
		this.key = key.toString();
		this.value = value;		
		
	}
	
	public String getKey() { return key; }
	public void setKey(String key) { this.key = key; }
	
	public Object getValue() { return value; }
	public void setValue(Object value) { this.value = value; }	

	public enum AttributeIdentifier {
		LABEL("label", String.class),
		VALUE("value", Object.class),
		HEIGHT("height", Integer.class),
		WIDTH("width", Integer.class),
		TITLE("title", String.class),
		IDENTIFIER("identifier", String.class),
		URL("url", String.class),
		BASE64_ENCODED_IMAGE("base64_encoded_image", String.class),
		RELATED_RECORD_ID ("related_record_id", Long.class),
		RELATED_OBJECT_RECORD ("related_object_record", ObjectRecord.class),
		RELATED_ACCOUNT_ID ("related_account_id", Integer.class);
		
		private final String identifier;
		private final Class<?> attributeValueType;
		
		private AttributeIdentifier(String identifier, Class<?> attributeValueType) {
			this.identifier = identifier;
			this.attributeValueType = attributeValueType;
		}
		
		public Class<?> getAttributeValueType() {
			return attributeValueType;
		}

		public Boolean isInstance(Object object) {
			return this.getAttributeValueType().isInstance(object);
		}
		
		public static Boolean isValid(String identifier) {
			try { 
				getIdentifier(identifier); 
			} catch (IllegalArgumentException e) { 
				return false;
			}
			return true;
		}
		
		public static AttributeIdentifier getIdentifier(String identifier) {
			return valueOf(identifier.toUpperCase());
		}
		
		public String toString() {
			return this.identifier;
		}
	}

}