/**
  *	Copyright (C) @YEAR@ Vernon Systems Limited
  *
  *	Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), 
  *	to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, 
  *	and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
  *
  *	The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
  *
  *	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  *	FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
  *	WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
package com.ehive.api.domain.objects;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import com.ehive.api.domain.objects.Field.FieldIdentifier;
import com.ehive.api.exceptions.EHiveApiException;


public class FieldSet implements Serializable {

	private static final long serialVersionUID = 3225024029582671172L;
	
	private String identifier;
	private List<FieldRow> fieldRows = new ArrayList<FieldRow>();
	
	public FieldSet() {}
		
	public FieldSet(String identifier) {
		this.identifier = identifier;
	}
	
	public String getIdentifier() { return identifier; }
	public void setIdentifier(String fieldSetIdentifier) { this.identifier = fieldSetIdentifier; }

	public List<FieldRow> getFieldRows() { return fieldRows; }
	public void setFieldRows(List<FieldRow> fieldRows) { this.fieldRows = fieldRows; }

	public List<Field> getFieldsByFieldIdentifier(String fieldIdentifier) throws EHiveApiException {
		if (FieldIdentifier.isValid(fieldIdentifier)) {
			return getFieldsByFieldIdentifier(FieldIdentifier.valueOf(fieldIdentifier));
		} else {
			throw new EHiveApiException("The Field Set identifier entered was not a valid eHive Field Set identifier: \"" + identifier + "\". \nPlease check the API docs online for a list of valid Field Set identifiers.");
		}
	}

	public List<Field> getFieldsByFieldIdentifier(FieldIdentifier fieldIdentifiers) {
		List<Field> fields = new ArrayList<Field>();
		
		for (FieldRow fieldRow : this.getFieldRows()) {
			for (Field field : fieldRow.getFields()) {
				if (field.getIdentifier().equals(fieldIdentifiers.toString())) {
					fields.add(field);
				} 
			}
		}

		return fields;
	}
	
	interface FieldSetFieldMapper {
		public FieldIdentifier getFieldIdentifier();
	}

	public enum FieldSetIdentifier {
		TRANSFERRED_TO("transferred_to", TransferredToFieldIdentifier.values()),
		ACCESSION_DATE("accession_date", AccessionDateFieldIdentifier.values()),
		SUBJECT_ASSOCIATION_DESCRIPTION("subject_association_description", SubjectAssociationDescriptionFieldIdentifier.values()),
		ASSOCIATION_KEYWORD("association_keyword", AssociationKeywordFieldIdentifier.values()),
		BRIEF_DESCRIPTION("brief_description", BriefDescriptionFieldIdentifier.values()),
		CARRIER_TYPE("carrier_type", CarrierTypeFieldIdentifier.values()),
		CATALOGUED("catalogued", CataloguedFieldIdentifier.values()),
		CLASSIFICATION("classification", ClassificationFieldIdentifier.values()),
		COMMENTS("comments", CommentsFieldIdentifier.values()),
		COMPLETED_TREATMENT_DESCRIPTION("completed_treatment_description", CompletedTreatmentDescriptionFieldIdentifier.values()),
		COMPLETED_TREATMENT("completed_treatment", CompletedTreatmentFieldIdentifier.values()),
		CONDITION_AT_ACQUISITION("condition_at_acquisition", ConditionAtAcquisitionFieldIdentifier.values()),
		CONDITION("condition", ConditionFieldIdentifier.values()),
		CONSERVATION_PRIORITY("conservation_priority", ConservationPriorityFieldIdentifier.values()),
		CONTROLLING_INSTITUTION("controlling_institution", ControllingInstitutionFieldIdentifier.values()),
		COPYRIGHT("copyright", CopyrightFieldIdentifier.values()),
		CREDIT_LINE("credit_line", CreditLineFieldIdentifier.values()),
		CURRENT_CONDITION_DESCRIPTION("current_condition_description", CurrentConditionDescriptionFieldIdentifier.values()),
		CURRENT_RECORD_STATUS("current_record_status", CurrentRecordStatusFieldIdentifier.values()),
		DATE_MADE("date_made", DateMadeFieldIdentifier.values()),
		DEACCESSION_AUTHORISER("deaccession_authoriser", DeaccessionAuthoriserFieldIdentifier.values()),
		DEACCESSION_DATE("deaccession_date", DeaccessionDateFieldIdentifier.values()),
		DEACCESSION_METHOD("deaccession_method", DeaccessionMethodFieldIdentifier.values()),
		DEACCESSION_PROCEEDS("deaccession_proceeds", DeaccessionProceedsFieldIdentifier.values()),
		DEACCESSION_REASON("deaccession_reason", DeaccessionReasonFieldIdentifier.values()),
		DEACCESSION_STATUS("deaccession_status", DeaccessionStatusFieldIdentifier.values()),
		DEPARTMENT("department", DepartmentFieldIdentifier.values()),
		DISPLAY_DETAILS("display_details", DisplayDetailsFieldIdentifier.values()),
		DUBLIN_CORE("dublin_core", DublinCoreFieldIdentifier.values()),
		EDITION("edition", EditionFieldIdentifier.values()),
		FIELD_COLLECTION_DATE("field_collection_date", FieldCollectionDateFieldIdentifier.values()),
		FIELD_COLLECTION_METHOD("field_collection_method", FieldCollectionMethodFieldIdentifier.values()),
		FIELD_COLLECTION_DESCRIPTION("field_collection_description", FieldCollectionDescriptionFieldIdentifier.values()),
		FIELD_COLLECTION_PLACE_KEYWORD("field_collection_place_keyword", FieldCollectionPlaceKeywordFieldIdentifier.values()),
		FIELD_COLLECTION_REFERENCE("field_collection_reference", FieldCollectionReferenceFieldIdentifier.values()),
		FIELD_COLLECTOR("field_collector", FieldCollectorFieldIdentifier.values()),
		FILM_TYPE("film_type", FilmTypeFieldIdentifier.values()),
		FORMAT("format", FormatFieldIdentifier.values()),
		FUNDER("funder", FunderFieldIdentifier.values()),
		GENERAL_FLAG_ADMIN("general_flag_admin", GeneralFlagAdminFieldIdentifier.values()),
		GENERAL_NOTES_ACQUISITION("general_notes_acquisition", GeneralNotesAcquisitionFieldIdentifier.values()),
		GENERAL_NOTES_ADMIN("general_notes_admin", GeneralNotesAdminFieldIdentifier.values()),
		GENERAL_NOTES_OBJECT("general_notes_object", GeneralNotesObjectFieldIdentifier.values()),
		GENERAL_NOTES_PLACE_MARK("general_notes_place_mark", GeneralNotesPlaceMarkFieldIdentifier.values()),
		GEOLOGICAL_AGE("geological_age", GeologicalAgeFieldIdentifier.values()),
		GEOLOGICAL_FORMATION("geological_formation", GeologicalFormationFieldIdentifier.values()),
		HABITAT_DESCRIPTION("habitat_description", HabitatDescriptionFieldIdentifier.values()),
		HABITAT_KEYWORD("habitat_keyword", HabitatKeywordFieldIdentifier.values()),
		HANDLING_DETAILS("handling_details", HandlingDetailsFieldIdentifier.values()),
		INSCRIPTION("inscription", InscriptionFieldIdentifier.values()),
		ISBN_ISSN("isbn_issn", IsbnIssnFieldIdentifier.values()),
		ITEM_COUNT("item_count", ItemCountFieldIdentifier.values()),
		ITEM_COUNT_NOTES("item_count_notes", ItemCountNotesFieldIdentifier.values()),
		LANGUAGE("language", LanguageFieldIdentifier.values()),
		LOCATION("location", LocationFieldIdentifier.values()),
		LOCATION_NOTES("location_notes", LocationNotesFieldIdentifier.values()),
		MARINE_ENVIRONMENT("marine_environment", MarineEnvironmentFieldIdentifier.values()),
		MEASUREMENT_DESCRIPTION("measurement_description", MeasurementDescriptionFieldIdentifier.values()),
		MEDIUM_DESCRIPTION("medium_description", MediumDescriptionFieldIdentifier.values()),
		MEDIUM_MATERIAL("medium_material", MediumMaterialFieldIdentifier.values()),
		MOUNTING_FRAMING("mounting_framing", MountingFramingFieldIdentifier.values()),
		NAMED_COLLECTION("named_collection", NamedCollectionFieldIdentifier.values()),
		OBJECT_NUMBER("object_number", ObjectNumberFieldIdentifier.values()),
		OBJECT_TYPE("object_type", ObjectTypeFieldIdentifier.values()),
		OTHER_MAKER_CONTRIBUTOR("other_maker_contributor", OtherMakerContributorFieldIdentifier.values()),
		OTHER_NAME_TITLE("other_name_title", OtherNameTitleFieldIdentifier.values()),
		OTHER_NUMBER("other_number", OtherNumberFieldIdentifier.values()),
		PACKING_DETAILS("packing_details", PackingDetailsFieldIdentifier.values()),
		PART_ID("part_id", PartIdFieldIdentifier.values()),
		PART_HOLDINGS("part_holdings", PartHoldingsFieldIdentifier.values()),
		PHYSICAL_CHARACTERISTICS("physical_characteristics", PhysicalCharacteristicsFieldIdentifier.values()),
		PLACE_MARK("place_mark", PlaceMarkFieldIdentifier.values()),
		PLACE_MADE("place_made", PlaceMadeFieldIdentifier.values()),
		PORTFOLIO_TITLE("portfolio_title", PortfolioTitleFieldIdentifier.values()),
		PRICE_FOREIGN("price_foreign", PriceForeignFieldIdentifier.values()),
		PRICE_LOCAL("price_local", PriceLocalFieldIdentifier.values()),
		PRIMARY_CREATOR_MAKER("primary_creator_maker", PrimaryCreatorMakerFieldIdentifier.values()),
		PROPOSED_TREATMENT_DESCRIPTION("proposed_treatment_description", ProposedTreatmentDescriptionFieldIdentifier.values()),
		PROPOSED_TREATMENT("proposed_treatment", ProposedTreatmentFieldIdentifier.values()),
		PROVENANCE("provenance", ProvenanceFieldIdentifier.values()),
		PUBLICATION("publication", PublicationFieldIdentifier.values()),
		RECORD_STATUS("record_status", RecordStatusFieldIdentifier.values()),
		RELATED_ACQUISITION_NUMBER("related_acquisition_number", RelatedAcquisitionNumberFieldIdentifier.values()),
		RELATED_OBJECT("related_object", RelatedObjectFieldIdentifier.values()),
		RESTRICTION_TYPE("restriction_type", RestrictionTypeFieldIdentifier.values()),
		RISK("risk", RiskFieldIdentifier.values()),
		SERIES_NUMBER("series_number", SeriesNumberFieldIdentifier.values()),
		SERIES_TITLE("series_title", SeriesTitleFieldIdentifier.values()),
		SEX("sex", SexFieldIdentifier.values()),
		SHORE_ENVIRONMENT("shore_environment", ShoreEnvironmentFieldIdentifier.values()),
		SIGNIFICANCE("significance", SignificanceFieldIdentifier.values()),
		SITE_DESCRIPTION("site_description", SiteDescriptionFieldIdentifier.values()),
		SITE_KEYWORD("site_keyword", SiteKeywordFieldIdentifier.values()),
		SOUND_AUDIO("sound_audio", SoundAudioFieldIdentifier.values()),
		SPECIMEN_AGE("specimen_age", SpecimenAgeFieldIdentifier.values()),
		SPECIMEN_CATEGORY("specimen_category", SpecimenCategoryFieldIdentifier.values()),
		SPECIMEN_DETAILS("specimen_details", SpecimenDetailsFieldIdentifier.values()),
		SPINE_LABEL("spine_label", SpineLabelFieldIdentifier.values()),
		STORAGE_DETAILS("storage_details", StorageDetailsFieldIdentifier.values()),
		STORAGE_PRESERVATION_METHOD("storage_preservation_method", StoragePreservationMethodFieldIdentifier.values()),
		STRATIGRAPHY_DESCRIPTION("stratigraphy_description", StratigraphyDescriptionFieldIdentifier.values()),
		STRATIGRAPHY_KEYWORD("stratigraphy_keyword", StratigraphyKeywordFieldIdentifier.values()),
		STYLE_ICONOGRAPY("style_iconograpy", StyleIconograpyFieldIdentifier.values()),
		SUBJECT_KEYWORD("subject_keyword", SubjectKeywordFieldIdentifier.values()),
		TAXON("taxon", TaxonFieldIdentifier.values()),
		TECHNIQUE("technique", TechniqueFieldIdentifier.values()),
		NAME("name", NameFieldIdentifier.values()),
		WEB_PUBLIC_DESCRIPTION("web_public_description", WebPublicDescriptionFieldIdentifier.values()),
		EXTERNAL_DATABASE_ID("external_database_id", ExternalDatabaseIdFieldIdentifier.values()),
		SIMPLE_SUMMARY("simple_summary", SimpleSummaryFieldIdentifier.values()),
		SUBJECT_ASSOCIATION_EVENT("subject_association_event", SubjectAssociationEventFieldIdentifier.values()),
		TAG("tag", TagFieldIdentifier.values()),
		FAMILY_NAME("family_name", FamilyNameFieldIdentifier.values()),
		GIVEN_NAME("given_name", GivenNameFieldIdentifier.values()),
		ADDITIONAL_NAMES("additional_names", AdditionalNamesFieldIdentifier.values()),
		KNOWN_AS("known_as", KnownAsFieldIdentifier.values()),
		TITLE("title", TitleFieldIdentifier.values()),
		POSTNOMINALS("postnominals", PostnominalsFieldIdentifier.values()),
		ORGANISATION_NAME("organisation_name", OrganisationNameFieldIdentifier.values()),
		SORT_NAME("sort_name", SortNameFieldIdentifier.values()),
		OTHER_NAME_TYPE("other_name_type", OtherNameTypeFieldIdentifier.values()),
		DATE_OF_BIRTH("date_of_birth", DateOfBirthFieldIdentifier.values()),
		DATE_OF_DEATH("date_of_death", DateOfDeathFieldIdentifier.values()),
		PLACE_OF_BIRTH("place_of_birth", PlaceOfBirthFieldIdentifier.values()),
		PLACE_OF_DEATH("place_of_death", PlaceOfDeathFieldIdentifier.values()),
		URL("url", UrlFieldIdentifier.values()),
		RELATED_RECORD("related_record", RelatedRecordFieldIdentifier.values()),
		JOB_TITLE("job_title", JobTitleFieldIdentifier.values()),
		JOB_ROLE("job_role", JobRoleFieldIdentifier.values()),
		GENERAL_NOTES("general_notes", GeneralNotesFieldIdentifier.values()),
		ACTIVE_DATE("active_date", ActiveDateFieldIdentifier.values()),
		NATIONALITY("nationality", NationalityFieldIdentifier.values()),
		ETHNICITY("ethnicity", EthnicityFieldIdentifier.values()),
		ACQ_NUMBER("acq_number", AcqNumberFieldIdentifier.values()),
		ACQ_METHOD("acq_method", AcqMethodFieldIdentifier.values()),
		ACQ_REASON("acq_reason", AcqReasonFieldIdentifier.values()),
		ACQ_DATE("acq_date", AcqDateFieldIdentifier.values()),
		ACQ_AUTHORITY("acq_authority", AcqAuthorityFieldIdentifier.values()),
		ACQ_SOURCE("acq_source", AcqSourceFieldIdentifier.values()),
		LOT_VALUATION("lot_valuation", LotValuationFieldIdentifier.values()),
		LOT_PRICE_LOCAL("lot_price_local", LotPriceLocalFieldIdentifier.values()),
		LOT_PRICE_FOREIGN("lot_price_foreign", LotPriceForeignFieldIdentifier.values()),
		LOT_DESCRIPTION("lot_description", LotDescriptionFieldIdentifier.values()),
		ACQ_VALUATION("acq_valuation", AcqValuationFieldIdentifier.values()),
		LEGAL_STATUS("legal_status", LegalStatusFieldIdentifier.values()),
		LOAN_IN("loan_in", LoanInFieldIdentifier.values()),
		LOAN_OUT("loan_out", LoanOutFieldIdentifier.values()),
		EXHIBITION_HISTORY("exhibition_history", ExhibitionHistoryFieldIdentifier.values()),
		RESEARCH_ATTRIBUTION("research_attribution", ResearchAttributionFieldIdentifier.values()),
		FIELD_COLLECTION_NOTES("field_collection_notes", FieldCollectionNotesFieldIdentifier.values()),
		GEOLOGICAL_FORMATION_DESCRIPTION("geological_formation_description", GeologicalFormationDescriptionFieldIdentifier.values()),
		GEOLOGICAL_AGE_DESCRIPTION("geological_age_description", GeologicalAgeDescriptionFieldIdentifier.values()),
		GEOLOGICAL_FORM("geological_form", GeologicalFormFieldIdentifier.values()),
		MEASUREMENT_DETAILS("measurement_details", MeasurementDetailsFieldIdentifier.values()),
		PERIOD("period", PeriodFieldIdentifier.values()),
		TYPE_ID_RELIABILITY_LEVEL("type_id_reliability_level", TypeIdReliabilityLevelFieldIdentifier.values()),
		RECORD_ACQUISITION_LOT_RELATIONSHIP("record_acquisition_lot_relationship", RecordAcquisitionLotRelationshipFieldIdentifier.values()),
		ACQUISITION_LOT_RECORD_RELATIONSHIP("acquisition_lot_record_relationship", AcquisitionLotRecordRelationshipFieldIdentifier.values()),
		OBJECT_OBJECT_RELATIONSHIP("object_object_relationship", ObjectObjectRelationshipFieldIdentifier.values()),
		ACQ_STATUS("acq_status", AcqStatusFieldIdentifier.values()),
		ACQ_FUNDER("acq_funder", AcqFunderFieldIdentifier.values()),
		PRODUCTION_NOTES("production_notes", ProductionNotesFieldIdentifier.values()),
		PLACE_MARK_NAME("place_mark_name", PlaceMarkNameFieldIdentifier.values()),
		LATITUDE_LONGITUDE("latitude_longitude", LatitudeLongitudeFieldIdentifier.values()),
		ZOOM_LEVEL("zoom_level", ZoomLevelFieldIdentifier.values()),
		PLACE_MARK_NOTES("place_mark_notes", PlaceMarkNotesFieldIdentifier.values()),
		PLACE_MARK_ACCOUNT_RELATIONSHIP("place_mark_account_relationship", PlaceMarkAccountRelationshipFieldIdentifier.values()),
		VALUATION("valuation", ValuationFieldIdentifier.values()),
		LATEST_VALUATION("latest_valuation", LatestValuationFieldIdentifier.values()),
		LATEST_APPRAISAL_VALUATION("latest_appraisal_valuation", LatestAppraisalValuationFieldIdentifier.values()),
		LATEST_INSURANCE_VALUATION("latest_insurance_valuation", LatestInsuranceValuationFieldIdentifier.values()),
		LATEST_CONSERVATION_VALUATION("latest_conservation_valuation", LatestConservationValuationFieldIdentifier.values()),
		LATEST_OUTGOING_LOAN_VALUATION("latest_outgoing_loan_valuation", LatestOutgoingLoanValuationFieldIdentifier.values()),
		LOCATION_HISTORY("location_history", LocationHistoryFieldIdentifier.values());

		enum TransferredToFieldIdentifier implements FieldSetFieldMapper {
			TRANSFERRED_TO (FieldIdentifier.TRANSFERRED_TO);

			private final FieldIdentifier fieldIdentifier;
			
			private TransferredToFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum AccessionDateFieldIdentifier implements FieldSetFieldMapper {
			ACCESSION_DATE (FieldIdentifier.ACCESSION_DATE);

			private final FieldIdentifier fieldIdentifier;
			
			private AccessionDateFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum SubjectAssociationDescriptionFieldIdentifier implements FieldSetFieldMapper {
			SUBJECT_ASSOCIATION_DESCRIPTION (FieldIdentifier.SUBJECT_ASSOCIATION_DESCRIPTION);

			private final FieldIdentifier fieldIdentifier;
			
			private SubjectAssociationDescriptionFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum AssociationKeywordFieldIdentifier implements FieldSetFieldMapper {
			ASSOCIATION_KEYWORD (FieldIdentifier.ASSOCIATION_KEYWORD);

			private final FieldIdentifier fieldIdentifier;
			
			private AssociationKeywordFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum BriefDescriptionFieldIdentifier implements FieldSetFieldMapper {
			BRIEF_DESCRIPTION (FieldIdentifier.BRIEF_DESCRIPTION);

			private final FieldIdentifier fieldIdentifier;
			
			private BriefDescriptionFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum CarrierTypeFieldIdentifier implements FieldSetFieldMapper {
			CARRIER_TYPE (FieldIdentifier.CARRIER_TYPE);

			private final FieldIdentifier fieldIdentifier;
			
			private CarrierTypeFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum CataloguedFieldIdentifier implements FieldSetFieldMapper {
			CATALOGUED_DATE (FieldIdentifier.CATALOGUED_DATE),
			CATALOGUER (FieldIdentifier.CATALOGUER);

			private final FieldIdentifier fieldIdentifier;
			
			private CataloguedFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum ClassificationFieldIdentifier implements FieldSetFieldMapper {
			CLASSIFICATION (FieldIdentifier.CLASSIFICATION);

			private final FieldIdentifier fieldIdentifier;
			
			private ClassificationFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum CommentsFieldIdentifier implements FieldSetFieldMapper {
			COMMENTS (FieldIdentifier.COMMENTS),
			COMMENTS_DATE (FieldIdentifier.COMMENTS_DATE),
			COMMENTS_PERSON (FieldIdentifier.COMMENTS_PERSON);

			private final FieldIdentifier fieldIdentifier;
			
			private CommentsFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum CompletedTreatmentDescriptionFieldIdentifier implements FieldSetFieldMapper {
			COMPLETED_TREATMENT_DESCRIPTION (FieldIdentifier.COMPLETED_TREATMENT_DESCRIPTION);

			private final FieldIdentifier fieldIdentifier;
			
			private CompletedTreatmentDescriptionFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum CompletedTreatmentFieldIdentifier implements FieldSetFieldMapper {
			COMPLETED_TREATMENT_DATE (FieldIdentifier.COMPLETED_TREATMENT_DATE),
			COMPLETED_TREATMENT_KEYWORD (FieldIdentifier.COMPLETED_TREATMENT_KEYWORD),
			COMPLETED_TREATMENT_NOTES (FieldIdentifier.COMPLETED_TREATMENT_NOTES),
			COMPLETED_TREATMENT_PART_REFERENCE (FieldIdentifier.COMPLETED_TREATMENT_PART_REFERENCE),
			COMPLETED_TREATMENT_PERSON (FieldIdentifier.COMPLETED_TREATMENT_PERSON);

			private final FieldIdentifier fieldIdentifier;
			
			private CompletedTreatmentFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum ConditionAtAcquisitionFieldIdentifier implements FieldSetFieldMapper {
			CONDITION_AT_ACQUISITION (FieldIdentifier.CONDITION_AT_ACQUISITION);

			private final FieldIdentifier fieldIdentifier;
			
			private ConditionAtAcquisitionFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum ConditionFieldIdentifier implements FieldSetFieldMapper {
			CONDITION_DATE (FieldIdentifier.CONDITION_DATE),
			CONDITION_KEYWORD (FieldIdentifier.CONDITION_KEYWORD),
			CONDITION_NOTES (FieldIdentifier.CONDITION_NOTES),
			CONDITION_PART_REFERENCE_ASPECT (FieldIdentifier.CONDITION_PART_REFERENCE_ASPECT),
			CONDITION_PERSON (FieldIdentifier.CONDITION_PERSON);

			private final FieldIdentifier fieldIdentifier;
			
			private ConditionFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum ConservationPriorityFieldIdentifier implements FieldSetFieldMapper {
			CONSERVATION_PRIORITY (FieldIdentifier.CONSERVATION_PRIORITY);

			private final FieldIdentifier fieldIdentifier;
			
			private ConservationPriorityFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum ControllingInstitutionFieldIdentifier implements FieldSetFieldMapper {
			CONTROLLING_INSTITUTION (FieldIdentifier.CONTROLLING_INSTITUTION);

			private final FieldIdentifier fieldIdentifier;
			
			private ControllingInstitutionFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum CopyrightFieldIdentifier implements FieldSetFieldMapper {
			COPYRIGHT_EXPIRY_DATE (FieldIdentifier.COPYRIGHT_EXPIRY_DATE),
			COPYRIGHT_NOTES (FieldIdentifier.COPYRIGHT_NOTES),
			COPYRIGHT_OWNER (FieldIdentifier.COPYRIGHT_OWNER),
			COPYRIGHT_START_DATE (FieldIdentifier.COPYRIGHT_START_DATE),
			COPYRIGHT_TYPE (FieldIdentifier.COPYRIGHT_TYPE);

			private final FieldIdentifier fieldIdentifier;
			
			private CopyrightFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum CreditLineFieldIdentifier implements FieldSetFieldMapper {
			CREDIT_LINE (FieldIdentifier.CREDIT_LINE);

			private final FieldIdentifier fieldIdentifier;
			
			private CreditLineFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum CurrentConditionDescriptionFieldIdentifier implements FieldSetFieldMapper {
			CURRENT_CONDITION_DESCRIPTION (FieldIdentifier.CURRENT_CONDITION_DESCRIPTION);

			private final FieldIdentifier fieldIdentifier;
			
			private CurrentConditionDescriptionFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum CurrentRecordStatusFieldIdentifier implements FieldSetFieldMapper {
			CURRENT_RECORD_STATUS (FieldIdentifier.CURRENT_RECORD_STATUS);

			private final FieldIdentifier fieldIdentifier;
			
			private CurrentRecordStatusFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum DateMadeFieldIdentifier implements FieldSetFieldMapper {
			DATE_MADE (FieldIdentifier.DATE_MADE);

			private final FieldIdentifier fieldIdentifier;
			
			private DateMadeFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum DeaccessionAuthoriserFieldIdentifier implements FieldSetFieldMapper {
			DEACCESSION_AUTHORISER (FieldIdentifier.DEACCESSION_AUTHORISER),
			DEACCESSION_AUTHORISER_POSITION (FieldIdentifier.DEACCESSION_AUTHORISER_POSITION);

			private final FieldIdentifier fieldIdentifier;
			
			private DeaccessionAuthoriserFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum DeaccessionDateFieldIdentifier implements FieldSetFieldMapper {
			DEACCESSION_DATE (FieldIdentifier.DEACCESSION_DATE);

			private final FieldIdentifier fieldIdentifier;
			
			private DeaccessionDateFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum DeaccessionMethodFieldIdentifier implements FieldSetFieldMapper {
			DEACCESSION_METHOD (FieldIdentifier.DEACCESSION_METHOD);

			private final FieldIdentifier fieldIdentifier;
			
			private DeaccessionMethodFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum DeaccessionProceedsFieldIdentifier implements FieldSetFieldMapper {
			DEACCESSION_PROCEEDS (FieldIdentifier.DEACCESSION_PROCEEDS);

			private final FieldIdentifier fieldIdentifier;
			
			private DeaccessionProceedsFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum DeaccessionReasonFieldIdentifier implements FieldSetFieldMapper {
			DEACCESSION_REASON (FieldIdentifier.DEACCESSION_REASON);

			private final FieldIdentifier fieldIdentifier;
			
			private DeaccessionReasonFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum DeaccessionStatusFieldIdentifier implements FieldSetFieldMapper {
			DEACCESSION_STATUS (FieldIdentifier.DEACCESSION_STATUS);

			private final FieldIdentifier fieldIdentifier;
			
			private DeaccessionStatusFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum DepartmentFieldIdentifier implements FieldSetFieldMapper {
			DEPARTMENT (FieldIdentifier.DEPARTMENT);

			private final FieldIdentifier fieldIdentifier;
			
			private DepartmentFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum DisplayDetailsFieldIdentifier implements FieldSetFieldMapper {
			DISPLAY_DETAILS (FieldIdentifier.DISPLAY_DETAILS);

			private final FieldIdentifier fieldIdentifier;
			
			private DisplayDetailsFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum DublinCoreFieldIdentifier implements FieldSetFieldMapper {
			DUBLIN_CORE (FieldIdentifier.DUBLIN_CORE);

			private final FieldIdentifier fieldIdentifier;
			
			private DublinCoreFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum EditionFieldIdentifier implements FieldSetFieldMapper {
			EDITION (FieldIdentifier.EDITION);

			private final FieldIdentifier fieldIdentifier;
			
			private EditionFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum FieldCollectionDateFieldIdentifier implements FieldSetFieldMapper {
			FIELD_COLLECTION_DATE (FieldIdentifier.FIELD_COLLECTION_DATE),
			FIELD_COLLECTION_TIME (FieldIdentifier.FIELD_COLLECTION_TIME);

			private final FieldIdentifier fieldIdentifier;
			
			private FieldCollectionDateFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum FieldCollectionMethodFieldIdentifier implements FieldSetFieldMapper {
			FIELD_COLLECTION_METHOD (FieldIdentifier.FIELD_COLLECTION_METHOD);

			private final FieldIdentifier fieldIdentifier;
			
			private FieldCollectionMethodFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum FieldCollectionDescriptionFieldIdentifier implements FieldSetFieldMapper {
			FIELD_COLLECTION_DESCRIPTION (FieldIdentifier.FIELD_COLLECTION_DESCRIPTION);

			private final FieldIdentifier fieldIdentifier;
			
			private FieldCollectionDescriptionFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum FieldCollectionPlaceKeywordFieldIdentifier implements FieldSetFieldMapper {
			FIELD_COLLECTION_PLACE_KEYWORD (FieldIdentifier.FIELD_COLLECTION_PLACE_KEYWORD);

			private final FieldIdentifier fieldIdentifier;
			
			private FieldCollectionPlaceKeywordFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum FieldCollectionReferenceFieldIdentifier implements FieldSetFieldMapper {
			FIELD_COLLECTION_REFERENCE (FieldIdentifier.FIELD_COLLECTION_REFERENCE);

			private final FieldIdentifier fieldIdentifier;
			
			private FieldCollectionReferenceFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum FieldCollectorFieldIdentifier implements FieldSetFieldMapper {
			FIELD_COLLECTOR (FieldIdentifier.FIELD_COLLECTOR),
			FIELD_COLLECTOR_ROLE (FieldIdentifier.FIELD_COLLECTOR_ROLE);

			private final FieldIdentifier fieldIdentifier;
			
			private FieldCollectorFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum FilmTypeFieldIdentifier implements FieldSetFieldMapper {
			FILM_TYPE (FieldIdentifier.FILM_TYPE);

			private final FieldIdentifier fieldIdentifier;
			
			private FilmTypeFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum FormatFieldIdentifier implements FieldSetFieldMapper {
			FORMAT (FieldIdentifier.FORMAT);

			private final FieldIdentifier fieldIdentifier;
			
			private FormatFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum FunderFieldIdentifier implements FieldSetFieldMapper {
			FUNDER (FieldIdentifier.FUNDER),
			FUNDER_AMOUNT (FieldIdentifier.FUNDER_AMOUNT),
			FUNDER_TYPE (FieldIdentifier.FUNDER_TYPE);

			private final FieldIdentifier fieldIdentifier;
			
			private FunderFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum GeneralFlagAdminFieldIdentifier implements FieldSetFieldMapper {
			GENERAL_FLAG_ADMIN (FieldIdentifier.GENERAL_FLAG_ADMIN);

			private final FieldIdentifier fieldIdentifier;
			
			private GeneralFlagAdminFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum GeneralNotesAcquisitionFieldIdentifier implements FieldSetFieldMapper {
			GENERAL_NOTES_ACQUISITION (FieldIdentifier.GENERAL_NOTES_ACQUISITION);

			private final FieldIdentifier fieldIdentifier;
			
			private GeneralNotesAcquisitionFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum GeneralNotesAdminFieldIdentifier implements FieldSetFieldMapper {
			GENERAL_NOTES_ADMIN (FieldIdentifier.GENERAL_NOTES_ADMIN);

			private final FieldIdentifier fieldIdentifier;
			
			private GeneralNotesAdminFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum GeneralNotesObjectFieldIdentifier implements FieldSetFieldMapper {
			GENERAL_NOTES_OBJECT (FieldIdentifier.GENERAL_NOTES_OBJECT);

			private final FieldIdentifier fieldIdentifier;
			
			private GeneralNotesObjectFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum GeneralNotesPlaceMarkFieldIdentifier implements FieldSetFieldMapper {
			GENERAL_NOTES_PLACE_MARK (FieldIdentifier.GENERAL_NOTES_PLACE_MARK);

			private final FieldIdentifier fieldIdentifier;
			
			private GeneralNotesPlaceMarkFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum GeologicalAgeFieldIdentifier implements FieldSetFieldMapper {
			GEOLOGICAL_AGE (FieldIdentifier.GEOLOGICAL_AGE);

			private final FieldIdentifier fieldIdentifier;
			
			private GeologicalAgeFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum GeologicalFormationFieldIdentifier implements FieldSetFieldMapper {
			GEOLOGICAL_FORMATION (FieldIdentifier.GEOLOGICAL_FORMATION);

			private final FieldIdentifier fieldIdentifier;
			
			private GeologicalFormationFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum HabitatDescriptionFieldIdentifier implements FieldSetFieldMapper {
			HABITAT_DESCRIPTION (FieldIdentifier.HABITAT_DESCRIPTION);

			private final FieldIdentifier fieldIdentifier;
			
			private HabitatDescriptionFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum HabitatKeywordFieldIdentifier implements FieldSetFieldMapper {
			HABITAT_KEYWORD (FieldIdentifier.HABITAT_KEYWORD);

			private final FieldIdentifier fieldIdentifier;
			
			private HabitatKeywordFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum HandlingDetailsFieldIdentifier implements FieldSetFieldMapper {
			HANDLING_DETAILS (FieldIdentifier.HANDLING_DETAILS);

			private final FieldIdentifier fieldIdentifier;
			
			private HandlingDetailsFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum InscriptionFieldIdentifier implements FieldSetFieldMapper {
			INSCRIPTION (FieldIdentifier.INSCRIPTION);

			private final FieldIdentifier fieldIdentifier;
			
			private InscriptionFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum IsbnIssnFieldIdentifier implements FieldSetFieldMapper {
			ISBN_ISSN (FieldIdentifier.ISBN_ISSN);

			private final FieldIdentifier fieldIdentifier;
			
			private IsbnIssnFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum ItemCountFieldIdentifier implements FieldSetFieldMapper {
			ITEM_COUNT (FieldIdentifier.ITEM_COUNT);

			private final FieldIdentifier fieldIdentifier;
			
			private ItemCountFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum ItemCountNotesFieldIdentifier implements FieldSetFieldMapper {
			ITEM_COUNT_NOTES (FieldIdentifier.ITEM_COUNT_NOTES);

			private final FieldIdentifier fieldIdentifier;
			
			private ItemCountNotesFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum LanguageFieldIdentifier implements FieldSetFieldMapper {
			LANGUAGE (FieldIdentifier.LANGUAGE);

			private final FieldIdentifier fieldIdentifier;
			
			private LanguageFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum LocationFieldIdentifier implements FieldSetFieldMapper {
			LOCATION (FieldIdentifier.LOCATION);

			private final FieldIdentifier fieldIdentifier;
			
			private LocationFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum LocationNotesFieldIdentifier implements FieldSetFieldMapper {
			LOCATION_NOTES (FieldIdentifier.LOCATION_NOTES);

			private final FieldIdentifier fieldIdentifier;
			
			private LocationNotesFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum MarineEnvironmentFieldIdentifier implements FieldSetFieldMapper {
			MARINE_ENVIRONMENT (FieldIdentifier.MARINE_ENVIRONMENT);

			private final FieldIdentifier fieldIdentifier;
			
			private MarineEnvironmentFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum MeasurementDescriptionFieldIdentifier implements FieldSetFieldMapper {
			MEASUREMENT_DESCRIPTION (FieldIdentifier.MEASUREMENT_DESCRIPTION);

			private final FieldIdentifier fieldIdentifier;
			
			private MeasurementDescriptionFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum MediumDescriptionFieldIdentifier implements FieldSetFieldMapper {
			MEDIUM_DESCRIPTION (FieldIdentifier.MEDIUM_DESCRIPTION);

			private final FieldIdentifier fieldIdentifier;
			
			private MediumDescriptionFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum MediumMaterialFieldIdentifier implements FieldSetFieldMapper {
			MEDIUM_MATERIAL (FieldIdentifier.MEDIUM_MATERIAL);

			private final FieldIdentifier fieldIdentifier;
			
			private MediumMaterialFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum MountingFramingFieldIdentifier implements FieldSetFieldMapper {
			MOUNTING_FRAMING (FieldIdentifier.MOUNTING_FRAMING);

			private final FieldIdentifier fieldIdentifier;
			
			private MountingFramingFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum NamedCollectionFieldIdentifier implements FieldSetFieldMapper {
			NAMED_COLLECTION (FieldIdentifier.NAMED_COLLECTION);

			private final FieldIdentifier fieldIdentifier;
			
			private NamedCollectionFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum ObjectNumberFieldIdentifier implements FieldSetFieldMapper {
			OBJECT_NUMBER (FieldIdentifier.OBJECT_NUMBER);

			private final FieldIdentifier fieldIdentifier;
			
			private ObjectNumberFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum ObjectTypeFieldIdentifier implements FieldSetFieldMapper {
			OBJECT_TYPE (FieldIdentifier.OBJECT_TYPE);

			private final FieldIdentifier fieldIdentifier;
			
			private ObjectTypeFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum OtherMakerContributorFieldIdentifier implements FieldSetFieldMapper {
			OTHER_MAKER_CONTRIBUTOR (FieldIdentifier.OTHER_MAKER_CONTRIBUTOR),
			OTHER_MAKER_CONTRIBUTOR_ROLE (FieldIdentifier.OTHER_MAKER_CONTRIBUTOR_ROLE);

			private final FieldIdentifier fieldIdentifier;
			
			private OtherMakerContributorFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum OtherNameTitleFieldIdentifier implements FieldSetFieldMapper {
			OTHER_NAME_TITLE (FieldIdentifier.OTHER_NAME_TITLE),
			OTHER_NAME_TITLE_NOTES (FieldIdentifier.OTHER_NAME_TITLE_NOTES),
			OTHER_NAME_TITLE_TYPE (FieldIdentifier.OTHER_NAME_TITLE_TYPE);

			private final FieldIdentifier fieldIdentifier;
			
			private OtherNameTitleFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum OtherNumberFieldIdentifier implements FieldSetFieldMapper {
			OTHER_NUMBER (FieldIdentifier.OTHER_NUMBER),
			OTHER_NUMBER_TYPE (FieldIdentifier.OTHER_NUMBER_TYPE);

			private final FieldIdentifier fieldIdentifier;
			
			private OtherNumberFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum PackingDetailsFieldIdentifier implements FieldSetFieldMapper {
			PACKING_DETAILS (FieldIdentifier.PACKING_DETAILS);

			private final FieldIdentifier fieldIdentifier;
			
			private PackingDetailsFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum PartIdFieldIdentifier implements FieldSetFieldMapper {
			PART_ID (FieldIdentifier.PART_ID),
			PART_DESCRIPTION (FieldIdentifier.PART_DESCRIPTION);

			private final FieldIdentifier fieldIdentifier;
			
			private PartIdFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum PartHoldingsFieldIdentifier implements FieldSetFieldMapper {
			PART_HOLDINGS (FieldIdentifier.PART_HOLDINGS);

			private final FieldIdentifier fieldIdentifier;
			
			private PartHoldingsFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum PhysicalCharacteristicsFieldIdentifier implements FieldSetFieldMapper {
			PHYSICAL_CHARACTERISTICS (FieldIdentifier.PHYSICAL_CHARACTERISTICS);

			private final FieldIdentifier fieldIdentifier;
			
			private PhysicalCharacteristicsFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum PlaceMarkFieldIdentifier implements FieldSetFieldMapper {
			PLACE_MARK (FieldIdentifier.PLACE_MARK);

			private final FieldIdentifier fieldIdentifier;
			
			private PlaceMarkFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum PlaceMarkNotesFieldIdentifier implements FieldSetFieldMapper {
			PLACE_MARK_NOTES (FieldIdentifier.PLACE_MARK_NOTES);

			private final FieldIdentifier fieldIdentifier;
			
			private PlaceMarkNotesFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum PlaceMadeFieldIdentifier implements FieldSetFieldMapper {
			PLACE_MADE (FieldIdentifier.PLACE_MADE),
			PLACE_NOTES (FieldIdentifier.PLACE_NOTES);

			private final FieldIdentifier fieldIdentifier;
			
			private PlaceMadeFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum PortfolioTitleFieldIdentifier implements FieldSetFieldMapper {
			PORTFOLIO_TITLE (FieldIdentifier.PORTFOLIO_TITLE);

			private final FieldIdentifier fieldIdentifier;
			
			private PortfolioTitleFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum PriceForeignFieldIdentifier implements FieldSetFieldMapper {
			PRICE_FOREIGN (FieldIdentifier.PRICE_FOREIGN);

			private final FieldIdentifier fieldIdentifier;
			
			private PriceForeignFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum PriceLocalFieldIdentifier implements FieldSetFieldMapper {
			PRICE_LOCAL (FieldIdentifier.PRICE_LOCAL);

			private final FieldIdentifier fieldIdentifier;
			
			private PriceLocalFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum PrimaryCreatorMakerFieldIdentifier implements FieldSetFieldMapper {
			PRIMARY_CREATOR_MAKER (FieldIdentifier.PRIMARY_CREATOR_MAKER),
			PRIMARY_CREATOR_MAKER_ROLE (FieldIdentifier.PRIMARY_CREATOR_MAKER_ROLE);

			private final FieldIdentifier fieldIdentifier;
			
			private PrimaryCreatorMakerFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum ProposedTreatmentDescriptionFieldIdentifier implements FieldSetFieldMapper {
			PROPOSED_TREATMENT_DESCRIPTION (FieldIdentifier.PROPOSED_TREATMENT_DESCRIPTION);

			private final FieldIdentifier fieldIdentifier;
			
			private ProposedTreatmentDescriptionFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum ProposedTreatmentFieldIdentifier implements FieldSetFieldMapper {
			PROPOSED_TREATMENT_DATE (FieldIdentifier.PROPOSED_TREATMENT_DATE),
			PROPOSED_TREATMENT_KEYWORD (FieldIdentifier.PROPOSED_TREATMENT_KEYWORD),
			PROPOSED_TREATMENT_NOTES (FieldIdentifier.PROPOSED_TREATMENT_NOTES),
			PROPOSED_TREATMENT_PART_REFERENCE (FieldIdentifier.PROPOSED_TREATMENT_PART_REFERENCE),
			PROPOSED_TREATMENT_PERSON (FieldIdentifier.PROPOSED_TREATMENT_PERSON);

			private final FieldIdentifier fieldIdentifier;
			
			private ProposedTreatmentFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum ProvenanceFieldIdentifier implements FieldSetFieldMapper {
			PROVENANCE_DATE (FieldIdentifier.PROVENANCE_DATE),
			PROVENANCE_DETAILS (FieldIdentifier.PROVENANCE_DETAILS),
			PROVENANCE_PERSON (FieldIdentifier.PROVENANCE_PERSON),
			PROVENANCE_PLACE (FieldIdentifier.PROVENANCE_PLACE);

			private final FieldIdentifier fieldIdentifier;
			
			private ProvenanceFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum PublicationFieldIdentifier implements FieldSetFieldMapper {
			PUBLISHER (FieldIdentifier.PUBLISHER),
			PUBLICATION_DATE (FieldIdentifier.PUBLICATION_DATE),
			PUBLICATION_PLACE (FieldIdentifier.PUBLICATION_PLACE);

			private final FieldIdentifier fieldIdentifier;
			
			private PublicationFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum RecordStatusFieldIdentifier implements FieldSetFieldMapper {
			RECORD_STATUS (FieldIdentifier.RECORD_STATUS);

			private final FieldIdentifier fieldIdentifier;
			
			private RecordStatusFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum RelatedAcquisitionNumberFieldIdentifier implements FieldSetFieldMapper {
			RELATED_ACQUISITION_NUMBER (FieldIdentifier.RELATED_ACQUISITION_NUMBER),
			RELATED_ACQUISITION_NUMBER_TYPE (FieldIdentifier.RELATED_ACQUISITION_NUMBER_TYPE);

			private final FieldIdentifier fieldIdentifier;
			
			private RelatedAcquisitionNumberFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum RelatedObjectFieldIdentifier implements FieldSetFieldMapper {
			RELATED_OBJECT (FieldIdentifier.RELATED_OBJECT),
			RELATED_OBJECT_NOTES (FieldIdentifier.RELATED_OBJECT_NOTES),
			RELATED_OBJECT_TYPE (FieldIdentifier.RELATED_OBJECT_TYPE);

			private final FieldIdentifier fieldIdentifier;
			
			private RelatedObjectFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum RestrictionTypeFieldIdentifier implements FieldSetFieldMapper {
			RESTRICTION_TYPE (FieldIdentifier.RESTRICTION_TYPE);

			private final FieldIdentifier fieldIdentifier;
			
			private RestrictionTypeFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum RiskFieldIdentifier implements FieldSetFieldMapper {
			RISK_ASSESSED_BY (FieldIdentifier.RISK_ASSESSED_BY),
			RISK_ASSESSMENT (FieldIdentifier.RISK_ASSESSMENT),
			RISK_ASSESSMENT_DATE (FieldIdentifier.RISK_ASSESSMENT_DATE),
			RISK_ASSESSMENT_NOTES (FieldIdentifier.RISK_ASSESSMENT_NOTES),
			RISK_FACTOR (FieldIdentifier.RISK_FACTOR);

			private final FieldIdentifier fieldIdentifier;
			
			private RiskFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum SeriesNumberFieldIdentifier implements FieldSetFieldMapper {
			SERIES_NUMBER (FieldIdentifier.SERIES_NUMBER);

			private final FieldIdentifier fieldIdentifier;
			
			private SeriesNumberFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum SeriesTitleFieldIdentifier implements FieldSetFieldMapper {
			SERIES_TITLE (FieldIdentifier.SERIES_TITLE);

			private final FieldIdentifier fieldIdentifier;
			
			private SeriesTitleFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum SexFieldIdentifier implements FieldSetFieldMapper {
			SEX (FieldIdentifier.SEX);

			private final FieldIdentifier fieldIdentifier;
			
			private SexFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum ShoreEnvironmentFieldIdentifier implements FieldSetFieldMapper {
			SHORE_ENVIRONMENT (FieldIdentifier.SHORE_ENVIRONMENT);

			private final FieldIdentifier fieldIdentifier;
			
			private ShoreEnvironmentFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum SignificanceFieldIdentifier implements FieldSetFieldMapper {
			SIGNIFICANCE (FieldIdentifier.SIGNIFICANCE);

			private final FieldIdentifier fieldIdentifier;
			
			private SignificanceFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum SiteDescriptionFieldIdentifier implements FieldSetFieldMapper {
			SITE_DESCRIPTION (FieldIdentifier.SITE_DESCRIPTION);

			private final FieldIdentifier fieldIdentifier;
			
			private SiteDescriptionFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum SiteKeywordFieldIdentifier implements FieldSetFieldMapper {
			SITE_KEYWORD (FieldIdentifier.SITE_KEYWORD);

			private final FieldIdentifier fieldIdentifier;
			
			private SiteKeywordFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum SoundAudioFieldIdentifier implements FieldSetFieldMapper {
			SOUND_AUDIO (FieldIdentifier.SOUND_AUDIO);

			private final FieldIdentifier fieldIdentifier;
			
			private SoundAudioFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum SpecimenAgeFieldIdentifier implements FieldSetFieldMapper {
			SPECIMEN_AGE (FieldIdentifier.SPECIMEN_AGE);

			private final FieldIdentifier fieldIdentifier;
			
			private SpecimenAgeFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum SpecimenCategoryFieldIdentifier implements FieldSetFieldMapper {
			SPECIMEN_CATEGORY (FieldIdentifier.SPECIMEN_CATEGORY),
			SPECIMEN_CATEGORY_NOTES_COUNT (FieldIdentifier.SPECIMEN_CATEGORY_NOTES_COUNT);

			private final FieldIdentifier fieldIdentifier;
			
			private SpecimenCategoryFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum SpecimenDetailsFieldIdentifier implements FieldSetFieldMapper {
			SPECIMEN_DETAILS (FieldIdentifier.SPECIMEN_DETAILS);

			private final FieldIdentifier fieldIdentifier;
			
			private SpecimenDetailsFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum SpineLabelFieldIdentifier implements FieldSetFieldMapper {
			SPINE_LABEL (FieldIdentifier.SPINE_LABEL);

			private final FieldIdentifier fieldIdentifier;
			
			private SpineLabelFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum StorageDetailsFieldIdentifier implements FieldSetFieldMapper {
			STORAGE_DETAILS (FieldIdentifier.STORAGE_DETAILS);

			private final FieldIdentifier fieldIdentifier;
			
			private StorageDetailsFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum StoragePreservationMethodFieldIdentifier implements FieldSetFieldMapper {
			STORAGE_PRESERVATION_METHOD (FieldIdentifier.STORAGE_PRESERVATION_METHOD);

			private final FieldIdentifier fieldIdentifier;
			
			private StoragePreservationMethodFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum StratigraphyDescriptionFieldIdentifier implements FieldSetFieldMapper {
			STRATIGRAPHY_DESCRIPTION (FieldIdentifier.STRATIGRAPHY_DESCRIPTION);

			private final FieldIdentifier fieldIdentifier;
			
			private StratigraphyDescriptionFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum StratigraphyKeywordFieldIdentifier implements FieldSetFieldMapper {
			STRATIGRAPHY_KEYWORD (FieldIdentifier.STRATIGRAPHY_KEYWORD);

			private final FieldIdentifier fieldIdentifier;
			
			private StratigraphyKeywordFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum StyleIconograpyFieldIdentifier implements FieldSetFieldMapper {
			STYLE_ICONOGRAPHY (FieldIdentifier.STYLE_ICONOGRAPHY);

			private final FieldIdentifier fieldIdentifier;
			
			private StyleIconograpyFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum SubjectKeywordFieldIdentifier implements FieldSetFieldMapper {
			SUBJECT_KEYWORD (FieldIdentifier.SUBJECT_KEYWORD);

			private final FieldIdentifier fieldIdentifier;
			
			private SubjectKeywordFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum TaxonFieldIdentifier implements FieldSetFieldMapper {
			TAXON_DETERMINED_BY (FieldIdentifier.TAXON_DETERMINED_BY),
			TAXON_DETERMINED_DATE (FieldIdentifier.TAXON_DETERMINED_DATE),
			TAXONOMIC_CLASSIFICATION (FieldIdentifier.TAXONOMIC_CLASSIFICATION),
			TAXONOMIC_CLASSIFICATION_NOTES (FieldIdentifier.TAXONOMIC_CLASSIFICATION_NOTES),
			TAXONOMIC_QUALIFIER (FieldIdentifier.TAXONOMIC_QUALIFIER),
			TAXONOMIC_TYPE_INDICATOR (FieldIdentifier.TAXONOMIC_TYPE_INDICATOR);

			private final FieldIdentifier fieldIdentifier;
			
			private TaxonFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum TechniqueFieldIdentifier implements FieldSetFieldMapper {
			TECHNIQUE (FieldIdentifier.TECHNIQUE);

			private final FieldIdentifier fieldIdentifier;
			
			private TechniqueFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum NameFieldIdentifier implements FieldSetFieldMapper {
			NAME (FieldIdentifier.NAME);

			private final FieldIdentifier fieldIdentifier;
			
			private NameFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum WebPublicDescriptionFieldIdentifier implements FieldSetFieldMapper {
			WEB_PUBLIC_DESCRIPTION (FieldIdentifier.WEB_PUBLIC_DESCRIPTION);

			private final FieldIdentifier fieldIdentifier;
			
			private WebPublicDescriptionFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum ExternalDatabaseIdFieldIdentifier implements FieldSetFieldMapper {
			EXTERNAL_DATABASE_ID (FieldIdentifier.EXTERNAL_DATABASE_ID);

			private final FieldIdentifier fieldIdentifier;
			
			private ExternalDatabaseIdFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum SimpleSummaryFieldIdentifier implements FieldSetFieldMapper {
			SIMPLE_SUMMARY (FieldIdentifier.SIMPLE_SUMMARY);

			private final FieldIdentifier fieldIdentifier;
			
			private SimpleSummaryFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum SubjectAssociationEventFieldIdentifier implements FieldSetFieldMapper {
			SUBJECT_ASSOCIATION_EVENT (FieldIdentifier.SUBJECT_ASSOCIATION_EVENT);

			private final FieldIdentifier fieldIdentifier;
			
			private SubjectAssociationEventFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum TagFieldIdentifier implements FieldSetFieldMapper {
			TAG (FieldIdentifier.TAG);

			private final FieldIdentifier fieldIdentifier;
			
			private TagFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum FamilyNameFieldIdentifier implements FieldSetFieldMapper {
			FAMILY_NAME (FieldIdentifier.FAMILY_NAME);

			private final FieldIdentifier fieldIdentifier;
			
			private FamilyNameFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum GivenNameFieldIdentifier implements FieldSetFieldMapper {
			GIVEN_NAME (FieldIdentifier.GIVEN_NAME);

			private final FieldIdentifier fieldIdentifier;
			
			private GivenNameFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum AdditionalNamesFieldIdentifier implements FieldSetFieldMapper {
			ADDITIONAL_NAMES (FieldIdentifier.ADDITIONAL_NAMES);

			private final FieldIdentifier fieldIdentifier;
			
			private AdditionalNamesFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum KnownAsFieldIdentifier implements FieldSetFieldMapper {
			KNOWN_AS (FieldIdentifier.KNOWN_AS);

			private final FieldIdentifier fieldIdentifier;
			
			private KnownAsFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum TitleFieldIdentifier implements FieldSetFieldMapper {
			TITLE (FieldIdentifier.TITLE);

			private final FieldIdentifier fieldIdentifier;
			
			private TitleFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum PostnominalsFieldIdentifier implements FieldSetFieldMapper {
			POSTNOMINALS (FieldIdentifier.POSTNOMINALS);

			private final FieldIdentifier fieldIdentifier;
			
			private PostnominalsFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum OrganisationNameFieldIdentifier implements FieldSetFieldMapper {
			ORGANISATION_NAME (FieldIdentifier.ORGANISATION_NAME);

			private final FieldIdentifier fieldIdentifier;
			
			private OrganisationNameFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum SortNameFieldIdentifier implements FieldSetFieldMapper {
			SORT_NAME (FieldIdentifier.SORT_NAME);

			private final FieldIdentifier fieldIdentifier;
			
			private SortNameFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum OtherNameTypeFieldIdentifier implements FieldSetFieldMapper {
			OTHER_NAME_TYPE (FieldIdentifier.OTHER_NAME_TYPE),
			OTHER_NAME (FieldIdentifier.OTHER_NAME),
			OTHER_NAME_DATE (FieldIdentifier.OTHER_NAME_DATE);

			private final FieldIdentifier fieldIdentifier;
			
			private OtherNameTypeFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum DateOfBirthFieldIdentifier implements FieldSetFieldMapper {
			DATE_OF_BIRTH (FieldIdentifier.DATE_OF_BIRTH);

			private final FieldIdentifier fieldIdentifier;
			
			private DateOfBirthFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum DateOfDeathFieldIdentifier implements FieldSetFieldMapper {
			DATE_OF_DEATH (FieldIdentifier.DATE_OF_DEATH);

			private final FieldIdentifier fieldIdentifier;
			
			private DateOfDeathFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum PlaceOfBirthFieldIdentifier implements FieldSetFieldMapper {
			PLACE_OF_BIRTH (FieldIdentifier.PLACE_OF_BIRTH);

			private final FieldIdentifier fieldIdentifier;
			
			private PlaceOfBirthFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum PlaceOfDeathFieldIdentifier implements FieldSetFieldMapper {
			PLACE_OF_DEATH (FieldIdentifier.PLACE_OF_DEATH);

			private final FieldIdentifier fieldIdentifier;
			
			private PlaceOfDeathFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum UrlFieldIdentifier implements FieldSetFieldMapper {
			URL (FieldIdentifier.URL);

			private final FieldIdentifier fieldIdentifier;
			
			private UrlFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum RelatedRecordFieldIdentifier implements FieldSetFieldMapper {
			RELATED_RECORD (FieldIdentifier.RELATED_RECORD),
			RELATIONSHIP (FieldIdentifier.RELATIONSHIP),
			RELATED_NOTES (FieldIdentifier.RELATED_NOTES);

			private final FieldIdentifier fieldIdentifier;
			
			private RelatedRecordFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum JobTitleFieldIdentifier implements FieldSetFieldMapper {
			JOB_TITLE (FieldIdentifier.JOB_TITLE);

			private final FieldIdentifier fieldIdentifier;
			
			private JobTitleFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum JobRoleFieldIdentifier implements FieldSetFieldMapper {
			JOB_ROLE (FieldIdentifier.JOB_ROLE);

			private final FieldIdentifier fieldIdentifier;
			
			private JobRoleFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum GeneralNotesFieldIdentifier implements FieldSetFieldMapper {
			GENERAL_NOTES (FieldIdentifier.GENERAL_NOTES);

			private final FieldIdentifier fieldIdentifier;
			
			private GeneralNotesFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum ActiveDateFieldIdentifier implements FieldSetFieldMapper {
			ACTIVE_DATE (FieldIdentifier.ACTIVE_DATE),
			ACTIVE_PLACE (FieldIdentifier.ACTIVE_PLACE),
			ACTIVE_NOTES (FieldIdentifier.ACTIVE_NOTES);

			private final FieldIdentifier fieldIdentifier;
			
			private ActiveDateFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum NationalityFieldIdentifier implements FieldSetFieldMapper {
			NATIONALITY (FieldIdentifier.NATIONALITY),
			NATIONALITY_DATE (FieldIdentifier.NATIONALITY_DATE),
			NATIONALITY_NOTES (FieldIdentifier.NATIONALITY_NOTES);

			private final FieldIdentifier fieldIdentifier;
			
			private NationalityFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum EthnicityFieldIdentifier implements FieldSetFieldMapper {
			ETHNICITY (FieldIdentifier.ETHNICITY);

			private final FieldIdentifier fieldIdentifier;
			
			private EthnicityFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum AcqNumberFieldIdentifier implements FieldSetFieldMapper {
			ACQ_NUMBER (FieldIdentifier.ACQ_NUMBER);

			private final FieldIdentifier fieldIdentifier;
			
			private AcqNumberFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum AcqMethodFieldIdentifier implements FieldSetFieldMapper {
			ACQ_METHOD (FieldIdentifier.ACQ_METHOD);

			private final FieldIdentifier fieldIdentifier;
			
			private AcqMethodFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum AcqReasonFieldIdentifier implements FieldSetFieldMapper {
			ACQ_REASON (FieldIdentifier.ACQ_REASON);

			private final FieldIdentifier fieldIdentifier;
			
			private AcqReasonFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum AcqDateFieldIdentifier implements FieldSetFieldMapper {
			ACQ_DATE (FieldIdentifier.ACQ_DATE);

			private final FieldIdentifier fieldIdentifier;
			
			private AcqDateFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum AcqAuthorityFieldIdentifier implements FieldSetFieldMapper {
			ACQ_AUTHORITY (FieldIdentifier.ACQ_AUTHORITY);

			private final FieldIdentifier fieldIdentifier;
			
			private AcqAuthorityFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum AcqSourceFieldIdentifier implements FieldSetFieldMapper {
			ACQ_SOURCE (FieldIdentifier.ACQ_SOURCE),
			ACQ_SOURCE_ROLE (FieldIdentifier.ACQ_SOURCE_ROLE);

			private final FieldIdentifier fieldIdentifier;
			
			private AcqSourceFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum LotValuationFieldIdentifier implements FieldSetFieldMapper {
			LOT_VALUATION (FieldIdentifier.LOT_VALUATION);

			private final FieldIdentifier fieldIdentifier;
			
			private LotValuationFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum LotPriceLocalFieldIdentifier implements FieldSetFieldMapper {
			LOT_PRICE_LOCAL (FieldIdentifier.LOT_PRICE_LOCAL);

			private final FieldIdentifier fieldIdentifier;
			
			private LotPriceLocalFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum LotPriceForeignFieldIdentifier implements FieldSetFieldMapper {
			LOT_PRICE_FOREIGN (FieldIdentifier.LOT_PRICE_FOREIGN);

			private final FieldIdentifier fieldIdentifier;
			
			private LotPriceForeignFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum LotDescriptionFieldIdentifier implements FieldSetFieldMapper {
			LOT_DESCRIPTION (FieldIdentifier.LOT_DESCRIPTION);

			private final FieldIdentifier fieldIdentifier;
			
			private LotDescriptionFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum AcqValuationFieldIdentifier implements FieldSetFieldMapper {
			ACQ_VALUATION (FieldIdentifier.ACQ_VALUATION);

			private final FieldIdentifier fieldIdentifier;
			
			private AcqValuationFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum LegalStatusFieldIdentifier implements FieldSetFieldMapper {
			LEGAL_STATUS (FieldIdentifier.LEGAL_STATUS);

			private final FieldIdentifier fieldIdentifier;
			
			private LegalStatusFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum LoanInFieldIdentifier implements FieldSetFieldMapper {
			LOAN_IN (FieldIdentifier.LOAN_IN);

			private final FieldIdentifier fieldIdentifier;
			
			private LoanInFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum LoanOutFieldIdentifier implements FieldSetFieldMapper {
			LOAN_OUT (FieldIdentifier.LOAN_OUT);

			private final FieldIdentifier fieldIdentifier;
			
			private LoanOutFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum ExhibitionHistoryFieldIdentifier implements FieldSetFieldMapper {
			EXHIBITION_HISTORY (FieldIdentifier.EXHIBITION_HISTORY);

			private final FieldIdentifier fieldIdentifier;
			
			private ExhibitionHistoryFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum ResearchAttributionFieldIdentifier implements FieldSetFieldMapper {
			RESEARCH_ATTRIBUTION (FieldIdentifier.RESEARCH_ATTRIBUTION),
			RESEARCH_ATTRIBUTION_DATE (FieldIdentifier.RESEARCH_ATTRIBUTION_DATE),
			RESEARCH_ATTRIBUTION_PERSON (FieldIdentifier.RESEARCH_ATTRIBUTION_PERSON);

			private final FieldIdentifier fieldIdentifier;
			
			private ResearchAttributionFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum FieldCollectionNotesFieldIdentifier implements FieldSetFieldMapper {
			FIELD_COLLECTION_NOTES (FieldIdentifier.FIELD_COLLECTION_NOTES);

			private final FieldIdentifier fieldIdentifier;
			
			private FieldCollectionNotesFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum GeologicalFormationDescriptionFieldIdentifier implements FieldSetFieldMapper {
			GEOLOGICAL_FORMATION_DESCRIPTION (FieldIdentifier.GEOLOGICAL_FORMATION_DESCRIPTION);

			private final FieldIdentifier fieldIdentifier;
			
			private GeologicalFormationDescriptionFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum GeologicalAgeDescriptionFieldIdentifier implements FieldSetFieldMapper {
			GEOLOGICAL_AGE_DESCRIPTION (FieldIdentifier.GEOLOGICAL_AGE_DESCRIPTION);

			private final FieldIdentifier fieldIdentifier;
			
			private GeologicalAgeDescriptionFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum GeologicalFormFieldIdentifier implements FieldSetFieldMapper {
			GEOLOGICAL_FORM (FieldIdentifier.GEOLOGICAL_FORM);

			private final FieldIdentifier fieldIdentifier;
			
			private GeologicalFormFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum MeasurementDetailsFieldIdentifier implements FieldSetFieldMapper {
			MEASUREMENT_ASPECT (FieldIdentifier.MEASUREMENT_ASPECT),
			MEASUREMENT_PART (FieldIdentifier.MEASUREMENT_PART),
			MEASUREMENT_UNIT (FieldIdentifier.MEASUREMENT_UNIT),
			MEASUREMENT_VALUE (FieldIdentifier.MEASUREMENT_VALUE);

			private final FieldIdentifier fieldIdentifier;
			
			private MeasurementDetailsFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum PeriodFieldIdentifier implements FieldSetFieldMapper {
			PERIOD (FieldIdentifier.PERIOD);

			private final FieldIdentifier fieldIdentifier;
			
			private PeriodFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum TypeIdReliabilityLevelFieldIdentifier implements FieldSetFieldMapper {
			TYPE_ID_RELIABILITY_LEVEL (FieldIdentifier.TYPE_ID_RELIABILITY_LEVEL);

			private final FieldIdentifier fieldIdentifier;
			
			private TypeIdReliabilityLevelFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum RecordAcquisitionLotRelationshipFieldIdentifier implements FieldSetFieldMapper {
			RECORD_ACQUISITION_LOT_RELATIONSHIP (FieldIdentifier.RECORD_ACQUISITION_LOT_RELATIONSHIP);

			private final FieldIdentifier fieldIdentifier;
			
			private RecordAcquisitionLotRelationshipFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum AcquisitionLotRecordRelationshipFieldIdentifier implements FieldSetFieldMapper {
			ACQUISITION_LOT_RECORD_RELATIONSHIP (FieldIdentifier.ACQUISITION_LOT_RECORD_RELATIONSHIP);

			private final FieldIdentifier fieldIdentifier;
			
			private AcquisitionLotRecordRelationshipFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum ObjectObjectRelationshipFieldIdentifier implements FieldSetFieldMapper {
			OBJECT_OBJECT_RELATIONSHIP (FieldIdentifier.OBJECT_OBJECT_RELATIONSHIP),
			OBJECT_OBJECT_RELATIONSHIP_NOTES (FieldIdentifier.OBJECT_OBJECT_RELATIONSHIP_NOTES);

			private final FieldIdentifier fieldIdentifier;
			
			private ObjectObjectRelationshipFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum AcqStatusFieldIdentifier implements FieldSetFieldMapper {
			ACQ_STATUS (FieldIdentifier.ACQ_STATUS);

			private final FieldIdentifier fieldIdentifier;
			
			private AcqStatusFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum AcqFunderFieldIdentifier implements FieldSetFieldMapper {
			ACQ_FUNDER (FieldIdentifier.ACQ_FUNDER),
			ACQ_FUNDING_AMOUNT (FieldIdentifier.ACQ_FUNDING_AMOUNT),
			ACQ_FUNDING_TYPE (FieldIdentifier.ACQ_FUNDING_TYPE);

			private final FieldIdentifier fieldIdentifier;
			
			private AcqFunderFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum ProductionNotesFieldIdentifier implements FieldSetFieldMapper {
			PRODUCTION_NOTES (FieldIdentifier.PRODUCTION_NOTES);

			private final FieldIdentifier fieldIdentifier;
			
			private ProductionNotesFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum PlaceMarkNameFieldIdentifier implements FieldSetFieldMapper {
			PLACE_MARK_NAME (FieldIdentifier.PLACE_MARK_NAME);

			private final FieldIdentifier fieldIdentifier;
			
			private PlaceMarkNameFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum LatitudeLongitudeFieldIdentifier implements FieldSetFieldMapper {
			LATITUDE (FieldIdentifier.LATITUDE),
			LONGITUDE (FieldIdentifier.LONGITUDE),
			DATUM (FieldIdentifier.DATUM);

			private final FieldIdentifier fieldIdentifier;
			
			private LatitudeLongitudeFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum ZoomLevelFieldIdentifier implements FieldSetFieldMapper {
			ZOOM_LEVEL (FieldIdentifier.ZOOM_LEVEL);

			private final FieldIdentifier fieldIdentifier;
			
			private ZoomLevelFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum PlaceMarkAccountRelationshipFieldIdentifier implements FieldSetFieldMapper {
			PLACE_MARK_ACCOUNT_RELATIONSHIP (FieldIdentifier.PLACE_MARK_ACCOUNT_RELATIONSHIP);

			private final FieldIdentifier fieldIdentifier;
			
			private PlaceMarkAccountRelationshipFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum ValuationFieldIdentifier implements FieldSetFieldMapper {
			VALUATION_TYPE (FieldIdentifier.VALUATION_TYPE),
			VALUATION_METHOD (FieldIdentifier.VALUATION_METHOD),
			VALUATION (FieldIdentifier.VALUATION),
			VALUATION_VALUER (FieldIdentifier.VALUATION_VALUER),
			VALUATION_DATE (FieldIdentifier.VALUATION_DATE),
			VALUATION_FOREIGN_CURRENCY_TYPE (FieldIdentifier.VALUATION_FOREIGN_CURRENCY_TYPE),
			VALUATION_FOREIGN_CURRENCY_VALUE (FieldIdentifier.VALUATION_FOREIGN_CURRENCY_VALUE),
			VALUATION_EXCHANGE_RATE (FieldIdentifier.VALUATION_EXCHANGE_RATE),
			VALUATION_NOTES (FieldIdentifier.VALUATION_NOTES);

			private final FieldIdentifier fieldIdentifier;
			
			private ValuationFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum LatestValuationFieldIdentifier implements FieldSetFieldMapper {
			LATEST_VALUATION (FieldIdentifier.LATEST_VALUATION);

			private final FieldIdentifier fieldIdentifier;
			
			private LatestValuationFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum LatestAppraisalValuationFieldIdentifier implements FieldSetFieldMapper {
			LATEST_APPRAISAL_VALUATION (FieldIdentifier.LATEST_APPRAISAL_VALUATION);

			private final FieldIdentifier fieldIdentifier;
			
			private LatestAppraisalValuationFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum LatestInsuranceValuationFieldIdentifier implements FieldSetFieldMapper {
			LATEST_INSURANCE_VALUATION (FieldIdentifier.LATEST_INSURANCE_VALUATION);

			private final FieldIdentifier fieldIdentifier;
			
			private LatestInsuranceValuationFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum LatestConservationValuationFieldIdentifier implements FieldSetFieldMapper {
			LATEST_CONSERVATION_VALUATION (FieldIdentifier.LATEST_CONSERVATION_VALUATION);

			private final FieldIdentifier fieldIdentifier;
			
			private LatestConservationValuationFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum LatestOutgoingLoanValuationFieldIdentifier implements FieldSetFieldMapper {
			LATEST_OUTGOING_LOAN_VALUATION (FieldIdentifier.LATEST_OUTGOING_LOAN_VALUATION);

			private final FieldIdentifier fieldIdentifier;
			
			private LatestOutgoingLoanValuationFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		enum LocationHistoryFieldIdentifier implements FieldSetFieldMapper {
			LOCATION_HISTORY (FieldIdentifier.LOCATION_HISTORY),
			LOCATION_HISTORY_DATE (FieldIdentifier.LOCATION_HISTORY_DATE),
			LOCATION_HISTORY_NOTES (FieldIdentifier.LOCATION_HISTORY_NOTES);

			private final FieldIdentifier fieldIdentifier;
			
			private LocationHistoryFieldIdentifier(FieldIdentifier fieldIdentifier) {
				this.fieldIdentifier = fieldIdentifier;
			}
			
			public FieldIdentifier getFieldIdentifier() {
				return this.fieldIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					FieldIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}

			public String toString() {
				return this.fieldIdentifier.toString();
			}
		}

		private final String identifier;
		private final Enum<?> [] validFieldIdentifier;
		
		private FieldSetIdentifier(String identifier, Enum<?> [] validFieldIdentifiers) {
			this.identifier = identifier;
			this.validFieldIdentifier = validFieldIdentifiers;
		}
		
		public Enum<?> [] getValidFieldIdentifiers() {
			return this.validFieldIdentifier;
		}
		
		public static Boolean isValid(String identifier) {
			try { 
				getFieldSetIdentifier(identifier); 
			} catch (IllegalArgumentException e) { 
				return false;
			}
			return true;
		}
		
		public static FieldSetIdentifier getFieldSetIdentifier(String identifier) {
			return valueOf(identifier.toUpperCase());
		}
		
		public String toString() {
			return this.identifier;
		}
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result
				+ ((fieldRows == null) ? 0 : fieldRows.hashCode());
		result = prime * result
				+ ((identifier == null) ? 0 : identifier.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		FieldSet other = (FieldSet) obj;
		if (fieldRows == null) {
			if (other.fieldRows != null)
				return false;
		} else if (!fieldRows.equals(other.fieldRows))
			return false;
		if (identifier == null) {
			if (other.identifier != null)
				return false;
		} else if (!identifier.equals(other.identifier))
			return false;
		return true;
	}
}