/**
  *	Copyright (C) @YEAR@ Vernon Systems Limited
  *
  *	Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), 
  *	to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, 
  *	and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
  *
  *	The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
  *
  *	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  *	FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
  *	WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
package com.ehive.api.domain.objects;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import com.ehive.api.domain.objects.Media.MediaIdentifier;

public class MediaSet implements Serializable {

	private static final long serialVersionUID = -8549626491347440628L;
	
	public MediaSet() {}
	
	public MediaSet(String identifier) {
		this.identifier = identifier;
	}
	
	private String identifier;
	private List<MediaRow> mediaRows = new ArrayList<MediaRow>();
	
	public String getIdentifier() { return identifier; }
	public void setIdentifier(String identifier) { this.identifier = identifier; }

	public List<MediaRow> getMediaRows() { return mediaRows; }
	public void setMediaRows(List<MediaRow> mediaRows) { this.mediaRows = mediaRows; }

	interface MediaSetMediaMapper {
		public MediaIdentifier getMediaIdentifier();
	}
	
	public enum MediaSetIdentifier {
		IMAGE("image", ImageMediaIdentifier.values());
		
		enum ImageMediaIdentifier implements MediaSetMediaMapper {
			IMAGE_O (MediaIdentifier.IMAGE_O),
			IMAGE_L (MediaIdentifier.IMAGE_L),
			IMAGE_M (MediaIdentifier.IMAGE_M),
			IMAGE_S (MediaIdentifier.IMAGE_S),
			IMAGE_T (MediaIdentifier.IMAGE_T),
			IMAGE_TS (MediaIdentifier.IMAGE_TS),
			IMAGE_NS (MediaIdentifier.IMAGE_NS);
	
			private final MediaIdentifier mediaIdentifier;
			
			private ImageMediaIdentifier(MediaIdentifier mediaIdentifier) {
				this.mediaIdentifier = mediaIdentifier;
			}
			
			public MediaIdentifier getMediaIdentifier() {
				return this.mediaIdentifier;
			}
			
			public static Boolean isValid(String identifier) {
				try { 
					MediaIdentifier.valueOf(identifier.toUpperCase()); 
				} catch (IllegalArgumentException e) { 
					return false;
				}
				return true;
			}
	
			public String toString() {
				return this.mediaIdentifier.toString();
			}
		}

		private final String identifier;
		private final Enum<?> [] validMediaIdentifier;
		
		private MediaSetIdentifier(String identifier, Enum<?> [] validMediaIdentifiers) {
			this.identifier = identifier;
			this.validMediaIdentifier = validMediaIdentifiers;
		}
		
		public Enum<?> [] getValidMediaIdentifiers() {
			return this.validMediaIdentifier;
		}
		
		public static Boolean isValid(String identifier) {
			try { 
				getMediaSetIdentifier(identifier); 
			} catch (IllegalArgumentException e) { 
				return false;
			}
			return true;
		}
		
		public static MediaSetIdentifier getMediaSetIdentifier(String identifier) {
			return valueOf(identifier.toUpperCase());
		}
		
		public String toString() {
			return this.identifier;
		}
	}
}
