/**
  *	Copyright (C) @YEAR@ Vernon Systems Limited
  *
  *	Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), 
  *	to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, 
  *	and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
  *
  *	The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
  *
  *	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  *	FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
  *	WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
package com.ehive.api.transport;

import java.io.BufferedReader;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.net.URI;
import java.net.URISyntaxException;
import java.util.Properties;

import org.apache.commons.lang3.StringUtils;
import org.apache.http.HttpResponse;
import org.apache.http.client.ClientProtocolException;
import org.apache.http.client.methods.HttpDelete;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.client.params.ClientPNames;
import org.apache.http.client.utils.URIUtils;
import org.apache.http.entity.StringEntity;
import org.apache.http.impl.client.DefaultHttpClient;

import com.ehive.api.exceptions.EHiveApiException;
import com.ehive.api.exceptions.EHiveFatalServerException;
import com.ehive.api.exceptions.EHiveForbiddenException;
import com.ehive.api.exceptions.EHiveNotFoundException;
import com.ehive.api.exceptions.EHiveStatusMessage;
import com.ehive.api.exceptions.EHiveUnauthorizedException;
import com.ehive.api.transport.oauth.ApiAuthorization;
import com.google.gson.Gson;

public class Transport {
	
	private String clientId;
	private String clientSecret;
	private String trackingId;
	
	
	private String apiUrl;

	private String pathToOauthPropertiesFile = "eHiveJavaApiClient.properties";
	private Properties oauthProperties;
	private Properties environmentProperties;
	
	private Integer retryAttempts = 0;
	private Integer authenticationRetryAttempts = 0;
	
	
	
	public Transport() throws EHiveApiException {
		
		oauthProperties = new Properties();
		
		try {
			oauthProperties.load(new FileInputStream("eHiveJavaApiClient.properties"));
									
		} catch (FileNotFoundException e) {	
			
			try {
				oauthProperties.setProperty(EHiveApiConstants.OAUTH_TOKEN, "defaultOAuthToken");
				oauthProperties.store(new FileOutputStream("eHiveJavaApiClient.properties"), null);
				
			} catch (FileNotFoundException e1) {
				throw new EHiveApiException(e1);

			} catch (IOException e1) {
				throw new EHiveApiException(e1);
			}
			
		} catch (IOException e) {
			throw new EHiveApiException(e);
		}		
		
	}
	
	public void setClientId(String clientId) { this.clientId = clientId; }
	public void setClientSecret(String clientSecret) { this.clientSecret = clientSecret; }
	public void setTrackingId(String trackingId) { this.trackingId = trackingId; }
	public void setApiUrl(String apiUrl) { this.apiUrl = apiUrl; }	
	
	
	public Transport(String clientId, String clientSecret, String trackingId, String pathToOauthPropertiesFile) throws EHiveApiException {
		this.clientId = clientId;
		this.clientSecret = clientSecret;
		this.trackingId = trackingId;
		this.pathToOauthPropertiesFile = pathToOauthPropertiesFile;
		
		this.oauthProperties = new Properties();
		this.environmentProperties = new Properties();
		try {
			this.oauthProperties.load(new FileInputStream(this.pathToOauthPropertiesFile));
			this.environmentProperties.load(this.getClass().getClassLoader().getResourceAsStream("META-INF/url.properties"));
			
			this.apiUrl = this.environmentProperties.getProperty("api.url");
		} catch (FileNotFoundException e) {
			throw new EHiveApiException("An Error occurred while trying to find the OAuth properties file. Please ensure that the path to the file you provided is correct and that it has read/write permissions enabled.", e);
		} catch (IOException e) {
			throw new EHiveApiException("An Error occurred while trying to read or write to the OAuth properties file. Please ensure that the path to the file you provided is correct and that it has read/write permissions enabled.", e);
		}
	}
	
	public Transport(String clientId, String clientSecret, String trackingId) throws EHiveApiException {
		this.clientId = clientId;
		this.clientSecret = clientSecret;
		this.trackingId = trackingId;
		
		this.oauthProperties = new Properties();
		this.environmentProperties = new Properties();
		try {
			
			this.environmentProperties.load(this.getClass().getClassLoader().getResourceAsStream("META-INF/url.properties"));			
			this.apiUrl = this.environmentProperties.getProperty("api.url");
		
		} catch (FileNotFoundException e) {
			throw new EHiveApiException("An Error occurred while trying to find the OAuth properties file. Please ensure that the path to the file you provided is correct and that it has read/write permissions enabled.", e);
		} catch (IOException e) {
			throw new EHiveApiException("An Error occurred while trying to read or write to the OAuth properties file. Please ensure that the path to the file you provided is correct and that it has read/write permissions enabled.", e);
		}
	}
	
	public Transport(String pathToOauthPropertiesFile) throws EHiveApiException {
		this.pathToOauthPropertiesFile = pathToOauthPropertiesFile;
		
		this.oauthProperties = new Properties();
		
			FileInputStream fileInputStream = null; 
			try {
				fileInputStream = new FileInputStream(this.pathToOauthPropertiesFile);
			
			} catch (FileNotFoundException e2) {
				throw new EHiveApiException("An Error occurred while trying to find the OAuth properties file. Please ensure that the path to the file you provided is correct and that it has read/write permissions enabled.", e2);
			}
		
			try {
				this.oauthProperties.load( fileInputStream );
			} catch (FileNotFoundException e1) {
				throw new EHiveApiException("An Error occurred while trying to find the OAuth properties file. Please ensure that the path to the file you provided is correct and that it has read/write permissions enabled.", e1);
			} catch (IOException e1) {
				throw new EHiveApiException("An Error occurred while trying to find the OAuth properties file. Please ensure that the path to the file you provided is correct and that it has read/write permissions enabled.", e1);
			}
			
			InputStream inputStream = Transport.class.getClassLoader().getResourceAsStream("url.properties");
			if ( inputStream != null) {
				try {
					this.environmentProperties = new Properties();
					this.environmentProperties.load(inputStream);
				} catch (IOException e) {
					throw new EHiveApiException("An Error occurred while trying to find the url.properties file", e);
				}
			} else {
				throw new EHiveApiException("An Error occurred while trying to find the url.properties file");
			}
						
			this.apiUrl = this.environmentProperties.getProperty("api.url");
			this.clientId = this.oauthProperties.getProperty(EHiveApiConstants.CLIENT_ID);
			this.clientSecret = this.oauthProperties.getProperty(EHiveApiConstants.CLIENT_SECRET);
			this.trackingId = this.oauthProperties.getProperty(EHiveApiConstants.TRACKING_ID);
	}
	
	public String get(String path, String queryString) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
	
		DefaultHttpClient defaultHttpClient = new DefaultHttpClient();
		HttpGet httpGet = new HttpGet();
		HttpResponse httpResponse = null;
		String response = null;

		try {
			if (StringUtils.isEmpty(queryString)) {
				queryString = "trackingId=" + this.trackingId;
			} else {
				queryString += "&trackingId=" + this.trackingId;
			}
			
			URI uri = URIUtils.createURI("https", this.apiUrl, -1, path, queryString, null);
	
			ApiAuthorization apiAuthorization = this.getAuthorization();
			
			httpGet.addHeader("Content-Type", "application/json");
			httpGet.addHeader("Authorization",  "Basic " + apiAuthorization.getOauthToken());
			httpGet.addHeader("Client-Id", apiAuthorization.getClientId());
			httpGet.addHeader("Grant-Type", apiAuthorization.getGrantType());
			
			httpGet.setURI(uri);
			
	        httpResponse = defaultHttpClient.execute(httpGet);
	        
	        BufferedReader bufferedReader = new BufferedReader(new InputStreamReader(httpResponse.getEntity().getContent()));
		    StringBuffer stringBuffer = new StringBuffer();
		    
		    while((response = bufferedReader.readLine()) != null) {
		    	stringBuffer.append(response);
		    }
		    
		    bufferedReader.close();
		    
		    response = stringBuffer.toString();
		    
		    Gson gson = new Gson();
		    EHiveStatusMessage eHiveStatusMessage = null;
		    
	        switch(httpResponse.getStatusLine().getStatusCode()) {
	        case 500:
	        	eHiveStatusMessage = gson.fromJson(response, EHiveStatusMessage.class);
	        	throw new EHiveFatalServerException(eHiveStatusMessage.toString());
	        case 404:
	        	throw new EHiveNotFoundException("Resource Not Found. Check that your request URL is valid.");
	        case 403:
	        	eHiveStatusMessage = gson.fromJson(response, EHiveStatusMessage.class);
	        	throw new EHiveForbiddenException(eHiveStatusMessage.toString());
	        case 401:
	        	if (this.retryAttempts < 3) {
	        		apiAuthorization = this.getAuthenticated();
	        		
	        		if (apiAuthorization == null) throw new EHiveApiException("OAuth Token is missing after the server said it has vended it. This is a fatal error and should be reported at http://forum.ehive.com.");
	        		
	        		this.retryAttempts++;
	        		
	        		response = this.get(path, queryString);
	        	} else {
	        		eHiveStatusMessage = gson.fromJson(response, EHiveStatusMessage.class);
		        	throw new EHiveUnauthorizedException(eHiveStatusMessage.toString());
	        	}
	        	break;
	        case 200:
	        	break;
	        default:
	        	eHiveStatusMessage = gson.fromJson(response, EHiveStatusMessage.class);
	        	throw new EHiveApiException(eHiveStatusMessage.toString());
	        }
		} catch (URISyntaxException e) {
			throw new EHiveApiException("An error occurred while trying to send a 'GET' request to the server-side API. The URI entered has invalid syntax.", e);
		} catch (ClientProtocolException e) {
			throw new EHiveApiException("An error occurred while trying to send a 'GET' request to the server-side API.", e);
		} catch (IOException e) {
			throw new EHiveApiException("An Error has occurred while trying to buffer the response from the server-side API. This is an critical server error so please log this issue at http://forum.ehive.com.", e);
		}
		return response;
	}
	
	public String post(String path, Object content, String queryString) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		
		DefaultHttpClient defaultHttpClient = new DefaultHttpClient();
		HttpPost httpPost = new HttpPost();
		Gson gson = new Gson();
		
		HttpResponse httpResponse = null;
		String response = null;
		
		try {
			if (StringUtils.isEmpty(queryString)) {
				queryString = "trackingId=" + this.trackingId;
			} else {
				queryString += "&trackingId=" + this.trackingId;
			}
			
			URI uri = URIUtils.createURI("https", this.apiUrl, -1, path, queryString, null);
	
			ApiAuthorization apiAuthorization = this.getAuthorization();
			
			httpPost.addHeader("Content-Type", "application/json");
			httpPost.addHeader("Authorization",  "Basic " + apiAuthorization.getOauthToken());
			httpPost.addHeader("Client-Id", apiAuthorization.getClientId());
			httpPost.addHeader("Grant-Type", apiAuthorization.getGrantType());
			
			httpPost.setURI(uri);
			
			StringEntity stringEntity = new StringEntity(gson.toJson(content));
			httpPost.setEntity(stringEntity);
			
	        httpResponse = defaultHttpClient.execute(httpPost);
	        
	        BufferedReader bufferedReader = new BufferedReader(new InputStreamReader(httpResponse.getEntity().getContent()));
		    StringBuffer stringBuffer = new StringBuffer();
		    
		    while((response = bufferedReader.readLine()) != null) {
		    	stringBuffer.append(response);
		    }
		    
		    bufferedReader.close();
		    
		    response = stringBuffer.toString();
		    
		    EHiveStatusMessage eHiveStatusMessage = null;
		    
	        switch(httpResponse.getStatusLine().getStatusCode()) {
	        case 500:
	        	eHiveStatusMessage = gson.fromJson(response, EHiveStatusMessage.class);
	        	throw new EHiveFatalServerException(eHiveStatusMessage.toString());
	        case 404:
	        	throw new EHiveNotFoundException("Resource Not Found. Check that your request URL is valid.");
	        case 403:
	        	eHiveStatusMessage = gson.fromJson(response, EHiveStatusMessage.class);
	        	throw new EHiveForbiddenException(eHiveStatusMessage.toString());
	        case 401:
	        	if (this.retryAttempts < 3) {
	        		apiAuthorization = this.getAuthenticated();
	        		
	        		if (apiAuthorization == null) throw new EHiveApiException("OAuth Token is missing after the server said it has vended it. This is a fatal error and should be reported at http://forum.ehive.com.");
	        		
	        		this.retryAttempts++;
	        		
	        		response = this.post(path, content, queryString);
	        	} else {
	        		eHiveStatusMessage = gson.fromJson(response, EHiveStatusMessage.class);
		        	throw new EHiveUnauthorizedException(eHiveStatusMessage.toString());
	        	}
	        	break;
	        case 200:
	        	break;
	        default:
	        	eHiveStatusMessage = gson.fromJson(response, EHiveStatusMessage.class);
	        	throw new EHiveApiException(eHiveStatusMessage.toString());
	        }
		} catch (URISyntaxException e) {
			throw new EHiveApiException("An error occurred while trying to send a 'POST' request to the server-side API. The URI entered has invalid syntax.", e);
		} catch (ClientProtocolException e) {
			throw new EHiveApiException("An error occurred while trying to send a 'POST' request to the server-side API.", e);
		} catch (IOException e) {
			throw new EHiveApiException("An Error has occurred while trying to buffer the response from the server-side API. This is an critical server error so please log this issue at http://forum.ehive.com.", e);
		}
		return response;
	}
	
	public String delete(String path) throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		
		DefaultHttpClient defaultHttpClient = new DefaultHttpClient();
		HttpDelete httpDelete = new HttpDelete();
		
		HttpResponse httpResponse = null;
		String response = null;
	
		try {
			String queryString = "trackingId=" + this.trackingId;
			
			URI uri = URIUtils.createURI("https", this.apiUrl, -1, path, queryString, null);
	
			ApiAuthorization apiAuthorization = this.getAuthorization();
			
			httpDelete.addHeader("Content-Type", "application/json");
			httpDelete.addHeader("Authorization",  "Basic " + apiAuthorization.getOauthToken());
			httpDelete.addHeader("Client-Id", apiAuthorization.getClientId());
			httpDelete.addHeader("Grant-Type", apiAuthorization.getGrantType());
			
			httpDelete.setURI(uri);
			
	        httpResponse = defaultHttpClient.execute(httpDelete);
	        
	        BufferedReader bufferedReader = new BufferedReader(new InputStreamReader(httpResponse.getEntity().getContent()));
		    StringBuffer stringBuffer = new StringBuffer();
		    
		    while((response = bufferedReader.readLine()) != null) {
		    	stringBuffer.append(response);
		    }
		    
		    bufferedReader.close();
		    
		    response = stringBuffer.toString();
		    
		    Gson gson = new Gson();
		    EHiveStatusMessage eHiveStatusMessage = null;
		    
	        switch(httpResponse.getStatusLine().getStatusCode()) {
	        case 500:
	        	eHiveStatusMessage = gson.fromJson(response, EHiveStatusMessage.class);
	        	throw new EHiveFatalServerException(eHiveStatusMessage.toString());
	        case 404:
	        	throw new EHiveNotFoundException("Resource Not Found. Check that your request URL is valid.");
	        case 403:
	        	eHiveStatusMessage = gson.fromJson(response, EHiveStatusMessage.class);
	        	throw new EHiveForbiddenException(eHiveStatusMessage.toString());
	        case 401:
	        	if (this.retryAttempts < 3) {
	        		apiAuthorization = this.getAuthenticated();
	        		
	        		if (apiAuthorization == null) throw new EHiveApiException("OAuth Token is missing after the server said it has vended it. This is a fatal error and should be reported at http://forum.ehive.com.");
	        		
	        		this.retryAttempts++;
	        		
	        		response = this.delete(path);
	        	} else {
	        		eHiveStatusMessage = gson.fromJson(response, EHiveStatusMessage.class);
		        	throw new EHiveUnauthorizedException(eHiveStatusMessage.toString());
	        	}
	        	break;
	        case 200:
	        	break;
	        default:
	        	eHiveStatusMessage = gson.fromJson(response, EHiveStatusMessage.class);
	        	throw new EHiveApiException(eHiveStatusMessage.toString());
	        }
		} catch (URISyntaxException e) {
			throw new EHiveApiException("An error occurred while trying to send a 'DELETE' request to the server-side API. The URI entered has invalid syntax.", e);
		} catch (ClientProtocolException e) {
			throw new EHiveApiException("An error occurred while trying to send a 'DELETE' request to the server-side API.", e);
		} catch (IOException e) {
			throw new EHiveApiException("An Error has occurred while trying to buffer the response from the server-side API. This is an critical server error so please log this issue at http://forum.ehive.com.", e);
		}
		return response;
	}
	
	private ApiAuthorization getAuthenticated() throws EHiveApiException, EHiveFatalServerException, EHiveNotFoundException, EHiveUnauthorizedException, EHiveForbiddenException {
		DefaultHttpClient defaultHttpClient = new DefaultHttpClient();
		HttpPost httpPost = new HttpPost();
		HttpResponse httpResponse = null;
	
		ApiAuthorization apiAuthorization = null;
		
		try {
			
			URI uri = URIUtils.createURI("https", this.apiUrl, -1, EHiveApiConstants.AUTHORIZATION_SERVER_PATH, "", null);
			
			httpPost.addHeader("Content-Type", "application/x-www-form-urlencoded");
			httpPost.addHeader("Authorization",  "OAuth");
			httpPost.addHeader("Client-Id", this.clientId);
			httpPost.addHeader("Client-Secret", this.clientSecret);
			httpPost.addHeader("Grant-Type", EHiveApiConstants.GRANT_TYPE_CLIENT_CREDENTIALS);
			
			httpPost.setURI(uri);

			defaultHttpClient.getParams().setParameter(ClientPNames.HANDLE_REDIRECTS, false);
			
			httpResponse = defaultHttpClient.execute(httpPost);
	        
	        String response = null;
	        
	        BufferedReader bufferedReader = new BufferedReader(new InputStreamReader(httpResponse.getEntity().getContent()));
		    StringBuffer stringBuffer = new StringBuffer();
		    
		    while((response = bufferedReader.readLine()) != null) {
		    	stringBuffer.append(response);
		    }
		    
		    bufferedReader.close();
		    
		    response = stringBuffer.toString();
		    
		    Gson gson = new Gson();
		    EHiveStatusMessage eHiveStatusMessage = null;
		    
	        switch(httpResponse.getStatusLine().getStatusCode()) {
	        case 500:
	        	eHiveStatusMessage = gson.fromJson(response, EHiveStatusMessage.class);
	        	throw new EHiveFatalServerException(eHiveStatusMessage.toString());
	        case 404:
	        	throw new EHiveNotFoundException("Resource Not Found. Check that your request URL is valid.");
	        case 403:
	        	eHiveStatusMessage = gson.fromJson(response, EHiveStatusMessage.class);
	        	throw new EHiveForbiddenException(eHiveStatusMessage.toString());
	        case 401:
	        	if (this.authenticationRetryAttempts < 3) {
	        		this.authenticationRetryAttempts++;
	        		
	        		apiAuthorization = this.getAuthenticated();
	        	} else {
	        		eHiveStatusMessage = gson.fromJson(response, EHiveStatusMessage.class);
		        	throw new EHiveUnauthorizedException(eHiveStatusMessage.toString());
	        	}
	        	break;
	        case 303:
	        	HttpGet httpGet = new HttpGet();
				
				try {
					
					uri = URIUtils.createURI("https", this.apiUrl.replace("/api",""), -1, httpResponse.getFirstHeader("Location").getValue(), "", null);
					
					httpGet.setParams(httpResponse.getParams());
					httpGet.setHeaders(httpResponse.getAllHeaders());
					
					httpGet.setURI(uri);
					
				} catch (URISyntaxException e) {
					e.printStackTrace();
				} 
				
				httpResponse = defaultHttpClient.execute(httpGet);
		        
		        response = null;
		        
		        bufferedReader = new BufferedReader(new InputStreamReader(httpResponse.getEntity().getContent()));
			    stringBuffer = new StringBuffer();
			    
			    while((response = bufferedReader.readLine()) != null) {
			    	stringBuffer.append(response);
			    }
			    
			    bufferedReader.close();
			    
			    response = stringBuffer.toString();
			    
			    gson = new Gson();
			    
			    switch(httpResponse.getStatusLine().getStatusCode()) {
			    case 200:
			    	apiAuthorization = gson.fromJson(response.toString(), ApiAuthorization.class);
		        	
		        	this.oauthProperties.setProperty(EHiveApiConstants.OAUTH_TOKEN, apiAuthorization.getOauthToken());
		        	this.oauthProperties.store(new FileOutputStream(this.pathToOauthPropertiesFile), null);
		        	
		        	break;
			    case 404:
		        	throw new EHiveNotFoundException("Resource Not Found. Check that your request URL is valid.");
			    case 401:
			    	eHiveStatusMessage = gson.fromJson(response, EHiveStatusMessage.class);
		        	throw new EHiveUnauthorizedException(eHiveStatusMessage.toString());
			    case 500:
			    	eHiveStatusMessage = gson.fromJson(response, EHiveStatusMessage.class);
		        	throw new EHiveFatalServerException(eHiveStatusMessage.toString());
			    }
			    
	        case 200:
	        	apiAuthorization = gson.fromJson(response.toString(), ApiAuthorization.class);
	        	
	        	this.oauthProperties.setProperty(EHiveApiConstants.OAUTH_TOKEN, apiAuthorization.getOauthToken());
	        	this.oauthProperties.store(new FileOutputStream(this.pathToOauthPropertiesFile), null);
	        	
	        	break;
	        default:
	        	eHiveStatusMessage = gson.fromJson(response, EHiveStatusMessage.class);
	        	throw new EHiveApiException("An Error has occurred while trying to buffer the response from the server-side API. This is an critical server error so please log this issue at http://forum.ehive.com.");
	    	}
		} catch (URISyntaxException e) {
			throw new EHiveApiException("An error occurred while trying to send an OAuth token request to the server-side API. The URI entered has invalid syntax.", e);
		} catch (ClientProtocolException e) {
			throw new EHiveApiException("An error occurred while trying to retrieve and OAuth token from the server-side API.", e);
		} catch (FileNotFoundException e) {
			throw new EHiveApiException("An Error occurred while trying to find the OAuth properties file. Please ensure that the path to the file you provided is correct and that it has read/write permissions enabled.", e);
		} catch (IOException e) {
			throw new EHiveApiException("An Error has occurred while either trying to read or write to the OAuth properties file or while trying to buffer the response from the server-side API. Please ensure that the path to the file you provided is correct and that it has read/write permissions enabled.", e);
		} catch (NullPointerException e) {
			throw new EHiveApiException(e);
		}
		
		return apiAuthorization;
	}

	private ApiAuthorization getAuthorization() throws EHiveApiException {
		ApiAuthorization apiAuthorization = new ApiAuthorization();
		
		String oauthToken = this.oauthProperties.getProperty(EHiveApiConstants.OAUTH_TOKEN, "defaultOAuthToken");
		
		apiAuthorization.setClientId(this.clientId);
		apiAuthorization.setOauthToken(oauthToken);
		apiAuthorization.setGrantType(EHiveApiConstants.GRANT_TYPE_AUTHORIZATION_CODE);
		
		return apiAuthorization;
	}
}
